"""
Simple command line utility to stream the parsed UBX output of a u-blox GNSS device.

Usage (all args are optional):
ubxdump port="/dev/ttyACM1" baud=9600 timeout=5 ubxonly=0 validate=1 output=0
   parsebitfield=1 filter=*

output: 0 = parsed, 1 = binary, 2 = hexadecimal

If ubxonly=True (1), streaming will terminate on any non-UBX data (e.g. NMEA).

For help, type:
ubxdump -h

Created on 20 Aug 2021

:author: semuadmin
:copyright: SEMU Consulting © 2021
:license: BSD 3-Clause
"""

import sys
from serial import Serial
from pyubx2 import UBXReader, GET, VALCKSUM

# Output formats
PARSED = 0
BIN = 1
HEX = 2

# Default port settings - amend as required
PORT = "/dev/ttyACM1"
BAUD = 9600
TIMEOUT = 5


def stream_ubx(**kwargs):
    """
    Stream output to terminal.

    :param int port: (kwarg)  baud rate (/dev/ttyACM1)
    :param int baud: (kwarg) baud rate (9600)
    :param int timeout: (kwarg) timeout in seconds (5)
    :param int ubxonly: (kwarg) set to True to generate error on non-UBX data (0)
    :param int validate: (kwarg) validate checksum (1)
    :param int parsebf: (kwarg) parse bitfields (1)
    :param int output: (kwarg) 0=parsed, 1=binary, 2=hexadecimal (0)
    :param int filter: (kwarg) comma-separated list of UBX message identities to display (*)
    :raises: UBXStreamError (if ubxonly flag is 1 and stream contains non-UBX data)

    """

    try:
        port = kwargs.get("port", PORT).strip('"')
        baud = int(kwargs.get("baud", BAUD))
        timeout = int(kwargs.get("timeout", TIMEOUT))
        ubxonly = int(kwargs.get("ubxonly", 0))
        validate = int(kwargs.get("validate", VALCKSUM))
        output = int(kwargs.get("output", PARSED))
        parsebf = int(kwargs.get("parsebitfield", True))
        filt = kwargs.get("filter", "*")
        filtertxt = "" if filt == "*" else f", filtered by {filt}"
        print(
            f"\nStreaming from {port} at {baud} baud in",
            f"{['parsed','binary','hexadecimal'][output]} format{filtertxt}...\n",
        )
        stream = Serial(port, baud, timeout=timeout)
        ubr = UBXReader(
            stream,
            ubxonly=ubxonly,
            validate=validate,
            msgmode=GET,
            parsebitfield=parsebf,
        )
        for (raw, parsed) in ubr:
            if filt == "*" or parsed.identity in filt:
                if output == BIN:
                    print(raw)
                elif output == HEX:
                    print(raw.hex())
                else:
                    print(parsed)
    except KeyboardInterrupt:
        print("\nStreaming terminated by user\n")


def main():
    """
    CLI Entry point.

    args as per stream_ubx() method
    """

    if len(sys.argv) > 1:
        if sys.argv[1] in {"-h", "--h", "help", "-help", "--help", "-H"}:
            print(
                " ubxdump is a simple command line utility to stream",
                "the parsed UBX output of a u-blox GNSS device.\n\n",
                "Usage (all args are optional): ubxdump",
                f"port={PORT} baud={BAUD} timeout={TIMEOUT}",
                "ubxonly=0 validate=1 output=0 parsebitfield=1 ",
                "filter=*\n\n Type Ctrl-C to terminate.",
            )
            sys.exit()

    stream_ubx(**dict(arg.split("=") for arg in sys.argv[1:]))


if __name__ == "__main__":

    main()



"""
UBXReader class.

Reads and parses individual UBX messages from any stream which supports a read(n) -> bytes method.

Returns both the raw binary data (as bytes) and the parsed data (as a UBXMessage object).

If the 'ubxonly' parameter is set to 'True', the reader will raise a UBXStreamerError if
it encounters any non-UBX data. Otherwise, it will ignore the non-UBX data and attempt
to carry on.

Created on 2 Oct 2020

:author: semuadmin
:copyright: SEMU Consulting © 2020
:license: BSD 3-Clause
"""

from pyubx2.ubxmessage import UBXMessage
from pyubx2.ubxhelpers import calc_checksum, val2bytes, bytes2val
import pyubx2.ubxtypes_core as ubt
import pyubx2.exceptions as ube

NMEAMSG = "Looks like NMEA data. Set ubxonly flag to 'False' to ignore."
# parser validation flag values
VALNONE = 0
VALCKSUM = 1


class UBXReader:
    """
    UBXReader class.
    """

    def __init__(self, stream, **kwargs):
        """Constructor.

        :param stream stream: input data stream
        :param bool ubxonly: (kwarg) check non-UBX data (False (ignore - default), True (reject))
        :param int validate: (kwarg) validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
        :param int msgmode: (kwarg) message mode (0=GET (default), 1=SET, 2=POLL)
        :param bool parsebitfield: (kwarg) parse bitfields True (default)/False
        :raises: UBXStreamError (if mode is invalid)

        """

        self._stream = stream
        self._ubx_only = kwargs.get("ubxonly", False)
        self._validate = kwargs.get("validate", VALCKSUM)
        self._parsebf = kwargs.get("parsebitfield", True)
        self._msgmode = kwargs.get("msgmode", 0)

        if self._msgmode not in (0, 1, 2):
            raise ube.UBXStreamError(
                f"Invalid stream mode {self._msgmode} - must be 0, 1 or 2"
            )

    def __iter__(self):
        """Iterator."""

        return self

    def __next__(self) -> tuple:
        """
        Return next item in iteration.

        :return: tuple of (raw_data as bytes, parsed_data as UBXMessage)
        :rtype: tuple
        :raises: StopIteration

        """

        (raw_data, parsed_data) = self.read()
        if raw_data is not None:
            return (raw_data, parsed_data)
        raise StopIteration

    def read(self) -> tuple:
        """
        Read the binary data from the stream buffer.

        :return: tuple of (raw_data as bytes, parsed_data as UBXMessage)
        :rtype: tuple
        :raises: UBXStreamError (if ubxonly=True and stream includes non-UBX data)

        """

        reading = True
        raw_data = None
        parsed_data = None

        byte1 = self._stream.read(1)  # read the first byte

        while reading:
            is_ubx = False
            is_nmea = False
            if len(byte1) < 1:  # EOF
                break
            if byte1 == ubt.UBX_HDR[0:1]:
                byte2 = self._stream.read(1)
                if len(byte2) < 1:  # EOF
                    break
                if byte2 == ubt.UBX_HDR[1:2]:
                    is_ubx = True
            if is_ubx:  # it's a UBX message
                byten = self._stream.read(4)
                if len(byten) < 4:  # EOF
                    break
                clsid = byten[0:1]
                msgid = byten[1:2]
                lenb = byten[2:4]
                leni = int.from_bytes(lenb, "little", signed=False)
                byten = self._stream.read(leni + 2)
                if len(byten) < leni + 2:  # EOF
                    break
                plb = byten[0:leni]
                cksum = byten[leni : leni + 2]
                raw_data = ubt.UBX_HDR + clsid + msgid + lenb + plb + cksum
                parsed_data = self.parse(
                    raw_data,
                    validate=self._validate,
                    msgmode=self._msgmode,
                    parsebitfield=self._parsebf,
                )
                reading = False
            else:  # it's not a UBX message (NMEA or something else)
                prevbyte = byte1
                byte1 = self._stream.read(1)
                if prevbyte == b"\x24" and byte1 in (b"\x47", b"\x50"):  # "$G" or "$P"
                    is_nmea = True  # looks like an NMEA message
                if self._ubx_only:  # raise error and quit
                    nmeawarn = NMEAMSG if is_nmea else ""
                    raise ube.UBXStreamError(
                        f"Unknown data header {prevbyte + byte1}. {nmeawarn}"
                    )

        return (raw_data, parsed_data)

    @staticmethod
    def parse(message: bytes, **kwargs) -> object:
        """
        Parse UBX byte stream to UBXMessage object.

        Includes option to validate incoming payload length and checksum
        (the UBXMessage constructor can calculate and assign its own values anyway).

        :param bytes message: binary message to parse
        :param int validate: (kwarg) validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
        :param int msgmode: (kwarg) message mode (0=GET (default), 1=SET, 2=POLL)
        :param bool parsebitfield: (kwarg) parse bitfields True (default)/False
        :return: UBXMessage object
        :rtype: UBXMessage
        :raises: UBXParseError (if data stream contains invalid data or unknown message type)

        """

        msgmode = kwargs.get("msgmode", ubt.GET)
        validate = kwargs.get("validate", VALCKSUM)
        parsebf = kwargs.get("parsebitfield", True)

        if msgmode not in (0, 1, 2):
            raise ube.UBXParseError(
                f"Invalid message mode {msgmode} - must be 0, 1 or 2"
            )

        lenm = len(message)
        hdr = message[0:2]
        clsid = message[2:3]
        msgid = message[3:4]
        lenb = message[4:6]
        if lenb == b"\x00\x00":
            payload = None
            leni = 0
        else:
            payload = message[6 : lenm - 2]
            leni = len(payload)
        ckm = message[lenm - 2 : lenm]
        if payload is not None:
            ckv = calc_checksum(clsid + msgid + lenb + payload)
        else:
            ckv = calc_checksum(clsid + msgid + lenb)
        if validate & VALCKSUM:
            if hdr != ubt.UBX_HDR:
                raise ube.UBXParseError(
                    (f"Invalid message header {hdr}" f" - should be {ubt.UBX_HDR}")
                )
            if leni != bytes2val(lenb, ubt.U2):
                raise ube.UBXParseError(
                    (
                        f"Invalid payload length {lenb}"
                        f" - should be {val2bytes(leni, ubt.U2)}"
                    )
                )
            if ckm != ckv:
                raise ube.UBXParseError(
                    (f"Message checksum {ckm}" f" invalid - should be {ckv}")
                )
        try:
            if payload is None:
                return UBXMessage(clsid, msgid, msgmode)
            return UBXMessage(
                clsid,
                msgid,
                msgmode,
                payload=payload,
                parsebitfield=parsebf,
            )
        except KeyError as err:
            modestr = ["GET", "SET", "POLL"][msgmode]
            raise ube.UBXParseError(
                (f"Unknown message type clsid {clsid}, msgid {msgid}, mode {modestr}")
            ) from err



"""
UBX Protocol Configuration Database Keys

Used by CFG_VALGET, CFG_VALSET and CFG_VALDEL message types

Format:
"keyname": (keyID, "type")

Created on 30 Nov 2020

Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG

:author: semuadmin
"""
# pylint: disable=too-many-lines

from pyubx2.ubxtypes_core import (
    E1,
    E2,
    I1,
    I2,
    I4,
    L,
    R4,
    R8,
    U1,
    U2,
    U4,
    U8,
    X1,
    X8,
)

# memory layer designators for CFG_VALSET & CFG_VALDEL
SET_LAYER_RAM = 1
SET_LAYER_BBR = 2
SET_LAYER_FLASH = 4

# memory layer designators for CFG_VALGET
POLL_LAYER_RAM = 0
POLL_LAYER_BBR = 1
POLL_LAYER_FLASH = 2
POLL_LAYER_DEFAULT = 7

# transaction state designators for CFG_VALSET & CFG_VALDEL
TXN_NONE = 0
TXN_START = 1
TXN_ONGOING = 2
TXN_COMMIT = 3

# bits 28..30 of Configuration KeyID represent
# storage length of Configuration Value in bytes
# KeyID >> 28 & 0b111
UBX_CONFIG_STORSIZE = {
    0x01: 1,
    0x02: 1,
    0x03: 2,
    0x04: 4,
    0x05: 8,
}

# NB: hyphens have been substituted for underscores in
# key names to make them valid attribute names
#
# PLEASE KEEP DICT SORTED BY KEY NAME
#
UBX_CONFIG_DATABASE = {
    "CFG_ANA_ORBMAXERR": (0x30230002, U2),
    "CFG_ANA_USE_ANA": (0x10230001, L),
    "CFG_BATCH_ENABLE": (0x10260013, L),
    "CFG_BATCH_EXTRAODO": (0x1026001B, L),
    "CFG_BATCH_EXTRAPVT": (0x1026001A, L),
    "CFG_BATCH_MAXENTRIES": (0x30260015, U2),
    "CFG_BATCH_PIOACTIVELOW": (0x10260018, L),
    "CFG_BATCH_PIOENABLE": (0x10260014, L),
    "CFG_BATCH_PIOID": (0x20260019, U1),
    "CFG_BATCH_WARNTHRS": (0x30260016, U2),
    "CFG_BDS_USE_PRN_1_TO_5": (0x10340014, L),  # aka CFG_BDS_USE_GEO_PRN
    "CFG_GEOFENCE_CONFLVL": (0x20240011, E1),
    "CFG_GEOFENCE_FENCE1_LAT": (0x40240021, I4),
    "CFG_GEOFENCE_FENCE1_LON": (0x40240022, I4),
    "CFG_GEOFENCE_FENCE1_RAD": (0x40240023, U4),
    "CFG_GEOFENCE_FENCE2_LAT": (0x40240031, I4),
    "CFG_GEOFENCE_FENCE2_LON": (0x40240032, I4),
    "CFG_GEOFENCE_FENCE2_RAD": (0x40240033, U4),
    "CFG_GEOFENCE_FENCE3_LAT": (0x40240041, I4),
    "CFG_GEOFENCE_FENCE3_LON": (0x40240042, I4),
    "CFG_GEOFENCE_FENCE3_RAD": (0x40240043, U4),
    "CFG_GEOFENCE_FENCE4_LAT": (0x40240051, I4),
    "CFG_GEOFENCE_FENCE4_LON": (0x40240052, I4),
    "CFG_GEOFENCE_FENCE4_RAD": (0x40240053, U4),
    "CFG_GEOFENCE_PIN": (0x20240014, U1),
    "CFG_GEOFENCE_PINPOL": (0x20240013, E1),
    "CFG_GEOFENCE_USE_FENCE1": (0x10240020, L),
    "CFG_GEOFENCE_USE_FENCE2": (0x10240030, L),
    "CFG_GEOFENCE_USE_FENCE3": (0x10240040, L),
    "CFG_GEOFENCE_USE_FENCE4": (0x10240050, L),
    "CFG_GEOFENCE_USE_PIO": (0x10240012, L),
    "CFG_HW_ANT_CFG_OPENDET": (0x10A30031, L),
    "CFG_HW_ANT_CFG_OPENDET_POL": (0x10A30032, L),
    "CFG_HW_ANT_CFG_PWRDOWN": (0x10A30033, L),
    "CFG_HW_ANT_CFG_PWRDOWN_POL": (0x10A30034, L),
    "CFG_HW_ANT_CFG_RECOVER": (0x10A30035, L),
    "CFG_HW_ANT_CFG_SHORTDET": (0x10A3002F, L),
    "CFG_HW_ANT_CFG_SHORTDET_POL": (0x10A30030, L),
    "CFG_HW_ANT_CFG_VOLTCTRL": (0x10A3002E, L),
    "CFG_HW_ANT_SUP_ENGINE": (0x20A30054, E1),
    "CFG_HW_ANT_SUP_OPEN_PIN": (0x20A30038, U1),
    "CFG_HW_ANT_SUP_OPEN_THR": (0x20A30056, U1),
    "CFG_HW_ANT_SUP_SHORT_PIN": (0x20A30037, U1),
    "CFG_HW_ANT_SUP_SHORT_THR": (0x20A30055, U1),
    "CFG_HW_ANT_SUP_SWITCH_PIN": (0x20A30036, U1),
    "CFG_HW_RF_LNA_MODE": (0x20A30057, E1),
    "CFG_I2C_ADDRESS": (0x20510001, U1),
    "CFG_I2C_ENABLED": (0x10510003, L),
    "CFG_I2C_EXTENDEDTIMEOUT": (0x10510002, L),
    "CFG_I2C_REMAP": (0x10510004, L),
    "CFG_I2CINPROT_NMEA": (0x10710002, L),
    "CFG_I2CINPROT_RTCM2X": (0x10710003, L),
    "CFG_I2CINPROT_RTCM3X": (0x10710004, L),
    "CFG_I2CINPROT_SPARTN": (0x10710005, L),
    "CFG_I2CINPROT_UBX": (0x10710001, L),
    "CFG_I2COUTPROT_NMEA": (0x10720002, L),
    "CFG_I2COUTPROT_RTCM3X": (0x10720004, L),
    "CFG_I2COUTPROT_UBX": (0x10720001, L),
    "CFG_INFMSG_NMEA_I2C": (0x20920006, X1),
    "CFG_INFMSG_NMEA_SPI": (0x2092000A, X1),
    "CFG_INFMSG_NMEA_UART1": (0x20920007, X1),
    "CFG_INFMSG_NMEA_UART2": (0x20920008, X1),
    "CFG_INFMSG_NMEA_USB": (0x20920009, X1),
    "CFG_INFMSG_UBX_I2C": (0x20920001, X1),
    "CFG_INFMSG_UBX_SPI": (0x20920005, X1),
    "CFG_INFMSG_UBX_UART1": (0x20920002, X1),
    "CFG_INFMSG_UBX_UART2": (0x20920003, X1),
    "CFG_INFMSG_UBX_USB": (0x20920004, X1),
    "CFG_ITFM_ANTSETTING": (0x20410010, E1),
    "CFG_ITFM_BBTHRESHOLD": (0x20410001, U1),
    "CFG_ITFM_CWTHRESHOLD": (0x20410002, U1),
    "CFG_ITFM_ENABLE": (0x1041000D, L),
    "CFG_ITFM_ENABLE_AUX": (0x10410013, L),
    "CFG_LOGFILTER_APPLY_ALL_FILTERS": (0x10DE0004, L),
    "CFG_LOGFILTER_MIN_INTERVAL": (0x30DE0005, U2),
    "CFG_LOGFILTER_ONCE_PER_WAKE_UP_ENA": (0x10DE0003, L),
    "CFG_LOGFILTER_POSITION_THRS": (0x40DE0008, U4),
    "CFG_LOGFILTER_RECORD_ENA": (0x10DE0002, L),
    "CFG_LOGFILTER_SPEED_THRS": (0x30DE0007, U2),
    "CFG_LOGFILTER_TIME_THRS": (0x30DE0006, U2),
    "CFG_MOT_GNSSDIST_THRS": (0x3025003B, U2),
    "CFG_MOT_GNSSSPEED_THRS": (0x20250038, U1),
    "CFG_MSGOUT_NMEA_ID_DTM_I2C": (0x209100A6, U1),
    "CFG_MSGOUT_NMEA_ID_DTM_SPI": (0x209100AA, U1),
    "CFG_MSGOUT_NMEA_ID_DTM_UART1": (0x209100A7, U1),
    "CFG_MSGOUT_NMEA_ID_DTM_UART2": (0x209100A8, U1),
    "CFG_MSGOUT_NMEA_ID_DTM_USB": (0x209100A9, U1),
    "CFG_MSGOUT_NMEA_ID_GBS_I2C": (0x209100DD, U1),
    "CFG_MSGOUT_NMEA_ID_GBS_SPI": (0x209100E1, U1),
    "CFG_MSGOUT_NMEA_ID_GBS_UART1": (0x209100DE, U1),
    "CFG_MSGOUT_NMEA_ID_GBS_UART2": (0x209100DF, U1),
    "CFG_MSGOUT_NMEA_ID_GBS_USB": (0x209100E0, U1),
    "CFG_MSGOUT_NMEA_ID_GGA_I2C": (0x209100BA, U1),
    "CFG_MSGOUT_NMEA_ID_GGA_SPI": (0x209100BE, U1),
    "CFG_MSGOUT_NMEA_ID_GGA_UART1": (0x209100BB, U1),
    "CFG_MSGOUT_NMEA_ID_GGA_UART2": (0x209100BC, U1),
    "CFG_MSGOUT_NMEA_ID_GGA_USB": (0x209100BD, U1),
    "CFG_MSGOUT_NMEA_ID_GLL_I2C": (0x209100C9, U1),
    "CFG_MSGOUT_NMEA_ID_GLL_SPI": (0x209100CD, U1),
    "CFG_MSGOUT_NMEA_ID_GLL_UART1": (0x209100CA, U1),
    "CFG_MSGOUT_NMEA_ID_GLL_UART2": (0x209100CB, U1),
    "CFG_MSGOUT_NMEA_ID_GLL_USB": (0x209100CC, U1),
    "CFG_MSGOUT_NMEA_ID_GNS_I2C": (0x209100B5, U1),
    "CFG_MSGOUT_NMEA_ID_GNS_SPI": (0x209100B9, U1),
    "CFG_MSGOUT_NMEA_ID_GNS_UART1": (0x209100B6, U1),
    "CFG_MSGOUT_NMEA_ID_GNS_UART2": (0x209100B7, U1),
    "CFG_MSGOUT_NMEA_ID_GNS_USB": (0x209100B8, U1),
    "CFG_MSGOUT_NMEA_ID_GRS_I2C": (0x209100CE, U1),
    "CFG_MSGOUT_NMEA_ID_GRS_SPI": (0x209100D2, U1),
    "CFG_MSGOUT_NMEA_ID_GRS_UART1": (0x209100CF, U1),
    "CFG_MSGOUT_NMEA_ID_GRS_UART2": (0x209100D0, U1),
    "CFG_MSGOUT_NMEA_ID_GRS_USB": (0x209100D1, U1),
    "CFG_MSGOUT_NMEA_ID_GSA_I2C": (0x209100BF, U1),
    "CFG_MSGOUT_NMEA_ID_GSA_SPI": (0x209100C3, U1),
    "CFG_MSGOUT_NMEA_ID_GSA_UART1": (0x209100C0, U1),
    "CFG_MSGOUT_NMEA_ID_GSA_UART2": (0x209100C1, U1),
    "CFG_MSGOUT_NMEA_ID_GSA_USB": (0x209100C2, U1),
    "CFG_MSGOUT_NMEA_ID_GST_I2C": (0x209100D3, U1),
    "CFG_MSGOUT_NMEA_ID_GST_SPI": (0x209100D7, U1),
    "CFG_MSGOUT_NMEA_ID_GST_UART1": (0x209100D4, U1),
    "CFG_MSGOUT_NMEA_ID_GST_UART2": (0x209100D5, U1),
    "CFG_MSGOUT_NMEA_ID_GST_USB": (0x209100D6, U1),
    "CFG_MSGOUT_NMEA_ID_GSV_I2C": (0x209100C4, U1),
    "CFG_MSGOUT_NMEA_ID_GSV_SPI": (0x209100C8, U1),
    "CFG_MSGOUT_NMEA_ID_GSV_UART1": (0x209100C5, U1),
    "CFG_MSGOUT_NMEA_ID_GSV_UART2": (0x209100C6, U1),
    "CFG_MSGOUT_NMEA_ID_GSV_USB": (0x209100C7, U1),
    "CFG_MSGOUT_NMEA_ID_RLM_I2C": (0x20910400, U1),
    "CFG_MSGOUT_NMEA_ID_RLM_SPI": (0x20910404, U1),
    "CFG_MSGOUT_NMEA_ID_RLM_UART1": (0x20910401, U1),
    "CFG_MSGOUT_NMEA_ID_RLM_UART2": (0x20910402, U1),
    "CFG_MSGOUT_NMEA_ID_RLM_USB": (0x20910403, U1),
    "CFG_MSGOUT_NMEA_ID_RMC_I2C": (0x209100AB, U1),
    "CFG_MSGOUT_NMEA_ID_RMC_SPI": (0x209100AF, U1),
    "CFG_MSGOUT_NMEA_ID_RMC_UART1": (0x209100AC, U1),
    "CFG_MSGOUT_NMEA_ID_RMC_UART2": (0x209100AD, U1),
    "CFG_MSGOUT_NMEA_ID_RMC_USB": (0x209100AE, U1),
    "CFG_MSGOUT_NMEA_ID_THS_I2C": (0x209100E2, U1),
    "CFG_MSGOUT_NMEA_ID_THS_SPI": (0x209100E6, U1),
    "CFG_MSGOUT_NMEA_ID_THS_UART1": (0x209100E3, U1),
    "CFG_MSGOUT_NMEA_ID_THS_UART2": (0x209100E4, U1),
    "CFG_MSGOUT_NMEA_ID_THS_USB": (0x209100E5, U1),
    "CFG_MSGOUT_NMEA_ID_VLW_I2C": (0x209100E7, U1),
    "CFG_MSGOUT_NMEA_ID_VLW_SPI": (0x209100EB, U1),
    "CFG_MSGOUT_NMEA_ID_VLW_UART1": (0x209100E8, U1),
    "CFG_MSGOUT_NMEA_ID_VLW_UART2": (0x209100E9, U1),
    "CFG_MSGOUT_NMEA_ID_VLW_USB": (0x209100EA, U1),
    "CFG_MSGOUT_NMEA_ID_VTG_I2C": (0x209100B0, U1),
    "CFG_MSGOUT_NMEA_ID_VTG_SPI": (0x209100B4, U1),
    "CFG_MSGOUT_NMEA_ID_VTG_UART1": (0x209100B1, U1),
    "CFG_MSGOUT_NMEA_ID_VTG_UART2": (0x209100B2, U1),
    "CFG_MSGOUT_NMEA_ID_VTG_USB": (0x209100B3, U1),
    "CFG_MSGOUT_NMEA_ID_ZDA_I2C": (0x209100D8, U1),
    "CFG_MSGOUT_NMEA_ID_ZDA_SPI": (0x209100DC, U1),
    "CFG_MSGOUT_NMEA_ID_ZDA_UART1": (0x209100D9, U1),
    "CFG_MSGOUT_NMEA_ID_ZDA_UART2": (0x209100DA, U1),
    "CFG_MSGOUT_NMEA_ID_ZDA_USB": (0x209100DB, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GGA_I2C": (0x20910661, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GGA_SPI": (0x20910665, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GGA_UART1": (0x20910662, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GGA_UART2": (0x20910663, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GGA_USB": (0x20910664, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GLL_I2C": (0x20910670, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GLL_SPI": (0x20910674, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GLL_UART1": (0x20910671, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GLL_UART2": (0x20910672, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GLL_USB": (0x20910673, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GNS_I2C": (0x2091065C, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GNS_SPI": (0x20910660, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GNS_UART1": (0x2091065D, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GNS_UART2": (0x2091065E, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GNS_USB": (0x2091065F, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GSA_I2C": (0x20910666, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GSA_SPI": (0x2091066A, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GSA_UART1": (0x20910667, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GSA_UART2": (0x20910668, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_GSA_USB": (0x20910669, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_RMC_I2C": (0x20910652, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_RMC_SPI": (0x20910656, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_RMC_UART1": (0x20910653, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_RMC_UART2": (0x20910654, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_RMC_USB": (0x20910655, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_VTG_I2C": (0x20910657, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_VTG_SPI": (0x2091065B, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_VTG_UART1": (0x20910658, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_VTG_UART2": (0x20910659, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_VTG_USB": (0x2091065A, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_ZDA_I2C": (0x2091067F, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_ZDA_SPI": (0x20910683, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_ZDA_UART1": (0x20910680, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_ZDA_UART2": (0x20910681, U1),
    "CFG_MSGOUT_NMEA_NAV2_ID_ZDA_USB": (0x20910682, U1),
    "CFG_MSGOUT_PUBX_ID_POLYP_I2C": (0x209100EC, U1),
    "CFG_MSGOUT_PUBX_ID_POLYP_SPI": (0x209100F0, U1),
    "CFG_MSGOUT_PUBX_ID_POLYP_UART1": (0x209100ED, U1),
    "CFG_MSGOUT_PUBX_ID_POLYP_UART2": (0x209100EE, U1),
    "CFG_MSGOUT_PUBX_ID_POLYP_USB": (0x209100EF, U1),
    "CFG_MSGOUT_PUBX_ID_POLYS_I2C": (0x209100F1, U1),
    "CFG_MSGOUT_PUBX_ID_POLYS_SPI": (0x209100F5, U1),
    "CFG_MSGOUT_PUBX_ID_POLYS_UART1": (0x209100F2, U1),
    "CFG_MSGOUT_PUBX_ID_POLYS_UART2": (0x209100F3, U1),
    "CFG_MSGOUT_PUBX_ID_POLYS_USB": (0x209100F4, U1),
    "CFG_MSGOUT_PUBX_ID_POLYT_I2C": (0x209100F6, U1),
    "CFG_MSGOUT_PUBX_ID_POLYT_SPI": (0x209100FA, U1),
    "CFG_MSGOUT_PUBX_ID_POLYT_UART1": (0x209100F7, U1),
    "CFG_MSGOUT_PUBX_ID_POLYT_UART2": (0x209100F8, U1),
    "CFG_MSGOUT_PUBX_ID_POLYT_USB": (0x209100F9, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1001_I2C": (0x209102A9, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1001_SPI": (0x209102AD, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1001_UART1": (0x209102AA, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1001_UART2": (0x209102AB, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1001_USB": (0x209102AC, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1002_I2C": (0x209102B3, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1002_SPI": (0x209102B7, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1002_UART1": (0x209102B4, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1002_UART2": (0x209102B5, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1002_USB": (0x209102B6, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1005_I2C": (0x209102BD, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1005_SPI": (0x209102C1, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1005_UART1": (0x209102BE, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1005_UART2": (0x209102BF, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1005_USB": (0x209102C0, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1006_I2C": (0x209102C2, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1006_SPI": (0x209102C6, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1006_UART1": (0x209102C3, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1006_UART2": (0x209102C4, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1006_USB": (0x209102C5, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1007_I2C": (0x209102C7, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1007_SPI": (0x209102CB, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1007_UART1": (0x209102C8, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1007_UART2": (0x209102C9, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1007_USB": (0x209102CA, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1009_I2C": (0x209102AE, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1009_SPI": (0x209102B2, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1009_UART1": (0x209102AF, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1009_UART2": (0x209102B0, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1009_USB": (0x209102B1, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1010_I2C": (0x209102B8, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1010_SPI": (0x209102BC, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1010_UART1": (0x209102B9, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1010_UART2": (0x209102BA, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1010_USB": (0x209102BB, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1074_I2C": (0x2091035E, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1074_SPI": (0x20910362, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1074_UART1": (0x2091035F, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1074_UART2": (0x20910360, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1074_USB": (0x20910361, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1077_I2C": (0x209102CC, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1077_SPI": (0x209102D0, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1077_UART1": (0x209102CD, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1077_UART2": (0x209102CE, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1077_USB": (0x209102CF, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1084_I2C": (0x20910363, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1084_SPI": (0x20910367, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1084_UART1": (0x20910364, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1084_UART2": (0x20910365, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1084_USB": (0x20910366, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1087_I2C": (0x209102D1, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1087_SPI": (0x209102D5, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1087_UART1": (0x209102D2, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1087_UART2": (0x209102D3, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1087_USB": (0x209102D4, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1094_I2C": (0x20910368, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1094_SPI": (0x2091036C, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1094_UART1": (0x20910369, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1094_UART2": (0x2091036A, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1094_USB": (0x2091036B, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1097_I2C": (0x20910318, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1097_SPI": (0x2091031C, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1097_UART1": (0x20910319, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1097_UART2": (0x2091031A, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1097_USB": (0x2091031B, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1124_I2C": (0x2091036D, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1124_SPI": (0x20910371, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1124_UART1": (0x2091036E, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1124_UART2": (0x2091036F, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1124_USB": (0x20910370, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1127_I2C": (0x209102D6, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1127_SPI": (0x209102DA, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1127_UART1": (0x209102D7, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1127_UART2": (0x209102D8, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1127_USB": (0x209102D9, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1230_I2C": (0x20910303, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1230_SPI": (0x20910307, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1230_UART1": (0x20910304, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1230_UART2": (0x20910305, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE1230_USB": (0x20910306, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_I2C": (0x209102FE, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_SPI": (0x20910302, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_UART1": (0x209102FF, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_UART2": (0x20910300, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_USB": (0x20910301, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_I2C": (0x20910381, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_SPI": (0x20910385, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART1": (0x20910382, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART2": (0x20910383, U1),
    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_USB": (0x20910384, U1),
    "CFG_MSGOUT_UBX_AID_ALM_I2C": (0x2091016E, U1),
    "CFG_MSGOUT_UBX_AID_ALM_SPI": (0x20910172, U1),
    "CFG_MSGOUT_UBX_AID_ALM_UART1": (0x2091016F, U1),
    "CFG_MSGOUT_UBX_AID_ALM_UART2": (0x20910170, U1),
    "CFG_MSGOUT_UBX_AID_ALM_USB": (0x20910171, U1),
    "CFG_MSGOUT_UBX_AID_AOP_I2C": (0x2091026D, U1),
    "CFG_MSGOUT_UBX_AID_AOP_SPI": (0x20910271, U1),
    "CFG_MSGOUT_UBX_AID_AOP_UART1": (0x2091026E, U1),
    "CFG_MSGOUT_UBX_AID_AOP_UART2": (0x2091026F, U1),
    "CFG_MSGOUT_UBX_AID_AOP_USB": (0x20910270, U1),
    "CFG_MSGOUT_UBX_AID_EPH_I2C": (0x20910164, U1),
    "CFG_MSGOUT_UBX_AID_EPH_SPI": (0x20910168, U1),
    "CFG_MSGOUT_UBX_AID_EPH_UART1": (0x20910165, U1),
    "CFG_MSGOUT_UBX_AID_EPH_UART2": (0x20910166, U1),
    "CFG_MSGOUT_UBX_AID_EPH_USB": (0x20910167, U1),
    "CFG_MSGOUT_UBX_AID_INI_I2C": (0x209100FB, U1),
    "CFG_MSGOUT_UBX_AID_INI_SPI": (0x209100FF, U1),
    "CFG_MSGOUT_UBX_AID_INI_UART1": (0x209100FC, U1),
    "CFG_MSGOUT_UBX_AID_INI_UART2": (0x209100FD, U1),
    "CFG_MSGOUT_UBX_AID_INI_USB": (0x209100FE, U1),
    "CFG_MSGOUT_UBX_DBG_31_I2C": (0x20910119, U1),
    "CFG_MSGOUT_UBX_DBG_31_SPI": (0x2091011D, U1),
    "CFG_MSGOUT_UBX_DBG_31_UART1": (0x2091011A, U1),
    "CFG_MSGOUT_UBX_DBG_31_UART2": (0x2091011B, U1),
    "CFG_MSGOUT_UBX_DBG_31_USB": (0x2091011C, U1),
    "CFG_MSGOUT_UBX_ESF_ALG_I2C": (0x2091010F, U1),
    "CFG_MSGOUT_UBX_ESF_ALG_SPI": (0x20910113, U1),
    "CFG_MSGOUT_UBX_ESF_ALG_UART1": (0x20910110, U1),
    "CFG_MSGOUT_UBX_ESF_ALG_UART2": (0x20910111, U1),
    "CFG_MSGOUT_UBX_ESF_ALG_USB": (0x20910112, U1),
    "CFG_MSGOUT_UBX_ESF_INS_I2C": (0x20910114, U1),
    "CFG_MSGOUT_UBX_ESF_INS_SPI": (0x20910118, U1),
    "CFG_MSGOUT_UBX_ESF_INS_UART1": (0x20910115, U1),
    "CFG_MSGOUT_UBX_ESF_INS_UART2": (0x20910116, U1),
    "CFG_MSGOUT_UBX_ESF_INS_USB": (0x20910117, U1),
    "CFG_MSGOUT_UBX_ESF_MEAS_I2C": (0x20910277, U1),
    "CFG_MSGOUT_UBX_ESF_MEAS_SPI": (0x2091027B, U1),
    "CFG_MSGOUT_UBX_ESF_MEAS_UART1": (0x20910278, U1),
    "CFG_MSGOUT_UBX_ESF_MEAS_UART2": (0x20910279, U1),
    "CFG_MSGOUT_UBX_ESF_MEAS_USB": (0x2091027A, U1),
    "CFG_MSGOUT_UBX_ESF_RAW_I2C": (0x2091029F, U1),
    "CFG_MSGOUT_UBX_ESF_RAW_SPI": (0x209102A3, U1),
    "CFG_MSGOUT_UBX_ESF_RAW_UART1": (0x209102A0, U1),
    "CFG_MSGOUT_UBX_ESF_RAW_UART2": (0x209102A1, U1),
    "CFG_MSGOUT_UBX_ESF_RAW_USB": (0x209102A2, U1),
    "CFG_MSGOUT_UBX_ESF_STATUS_I2C": (0x20910105, U1),
    "CFG_MSGOUT_UBX_ESF_STATUS_SPI": (0x20910109, U1),
    "CFG_MSGOUT_UBX_ESF_STATUS_UART1": (0x20910106, U1),
    "CFG_MSGOUT_UBX_ESF_STATUS_UART2": (0x20910107, U1),
    "CFG_MSGOUT_UBX_ESF_STATUS_USB": (0x20910108, U1),
    "CFG_MSGOUT_UBX_HNR_ATT_I2C": (0x20910377, U1),
    "CFG_MSGOUT_UBX_HNR_ATT_SPI": (0x2091037B, U1),
    "CFG_MSGOUT_UBX_HNR_ATT_UART1": (0x20910378, U1),
    "CFG_MSGOUT_UBX_HNR_ATT_UART2": (0x20910379, U1),
    "CFG_MSGOUT_UBX_HNR_ATT_USB": (0x2091037A, U1),
    "CFG_MSGOUT_UBX_HNR_INS_I2C": (0x20910372, U1),
    "CFG_MSGOUT_UBX_HNR_INS_SPI": (0x20910376, U1),
    "CFG_MSGOUT_UBX_HNR_INS_UART1": (0x20910373, U1),
    "CFG_MSGOUT_UBX_HNR_INS_UART2": (0x20910374, U1),
    "CFG_MSGOUT_UBX_HNR_INS_USB": (0x20910375, U1),
    "CFG_MSGOUT_UBX_HNR_PVT_I2C": (0x2091028B, U1),
    "CFG_MSGOUT_UBX_HNR_PVT_SPI": (0x2091028F, U1),
    "CFG_MSGOUT_UBX_HNR_PVT_UART1": (0x2091028C, U1),
    "CFG_MSGOUT_UBX_HNR_PVT_UART2": (0x2091028D, U1),
    "CFG_MSGOUT_UBX_HNR_PVT_USB": (0x2091028E, U1),
    "CFG_MSGOUT_UBX_LOG_INFO_I2C": (0x20910259, U1),
    "CFG_MSGOUT_UBX_LOG_INFO_SPI": (0x2091025D, U1),
    "CFG_MSGOUT_UBX_LOG_INFO_UART1": (0x2091025A, U1),
    "CFG_MSGOUT_UBX_LOG_INFO_UART2": (0x2091025B, U1),
    "CFG_MSGOUT_UBX_LOG_INFO_USB": (0x2091025C, U1),
    "CFG_MSGOUT_UBX_MON_COMMS_I2C": (0x2091034F, U1),
    "CFG_MSGOUT_UBX_MON_COMMS_SPI": (0x20910353, U1),
    "CFG_MSGOUT_UBX_MON_COMMS_UART1": (0x20910350, U1),
    "CFG_MSGOUT_UBX_MON_COMMS_UART2": (0x20910351, U1),
    "CFG_MSGOUT_UBX_MON_COMMS_USB": (0x20910352, U1),
    "CFG_MSGOUT_UBX_MON_HW_I2C": (0x209101B4, U1),
    "CFG_MSGOUT_UBX_MON_HW_SPI": (0x209101B8, U1),
    "CFG_MSGOUT_UBX_MON_HW_UART1": (0x209101B5, U1),
    "CFG_MSGOUT_UBX_MON_HW_UART2": (0x209101B6, U1),
    "CFG_MSGOUT_UBX_MON_HW_USB": (0x209101B7, U1),
    "CFG_MSGOUT_UBX_MON_HW2_I2C": (0x209101B9, U1),
    "CFG_MSGOUT_UBX_MON_HW2_SPI": (0x209101BD, U1),
    "CFG_MSGOUT_UBX_MON_HW2_UART1": (0x209101BA, U1),
    "CFG_MSGOUT_UBX_MON_HW2_UART2": (0x209101BB, U1),
    "CFG_MSGOUT_UBX_MON_HW2_USB": (0x209101BC, U1),
    "CFG_MSGOUT_UBX_MON_HW3_I2C": (0x20910354, U1),
    "CFG_MSGOUT_UBX_MON_HW3_SPI": (0x20910358, U1),
    "CFG_MSGOUT_UBX_MON_HW3_UART1": (0x20910355, U1),
    "CFG_MSGOUT_UBX_MON_HW3_UART2": (0x20910356, U1),
    "CFG_MSGOUT_UBX_MON_HW3_USB": (0x20910357, U1),
    "CFG_MSGOUT_UBX_MON_IO_I2C": (0x209101A5, U1),
    "CFG_MSGOUT_UBX_MON_IO_SPI": (0x209101A9, U1),
    "CFG_MSGOUT_UBX_MON_IO_UART1": (0x209101A6, U1),
    "CFG_MSGOUT_UBX_MON_IO_UART2": (0x209101A7, U1),
    "CFG_MSGOUT_UBX_MON_IO_USB": (0x209101A8, U1),
    "CFG_MSGOUT_UBX_MON_MSGPP_I2C": (0x20910196, U1),
    "CFG_MSGOUT_UBX_MON_MSGPP_SPI": (0x2091019A, U1),
    "CFG_MSGOUT_UBX_MON_MSGPP_UART1": (0x20910197, U1),
    "CFG_MSGOUT_UBX_MON_MSGPP_UART2": (0x20910198, U1),
    "CFG_MSGOUT_UBX_MON_MSGPP_USB": (0x20910199, U1),
    "CFG_MSGOUT_UBX_MON_RF_I2C": (0x20910359, U1),
    "CFG_MSGOUT_UBX_MON_RF_SPI": (0x2091035D, U1),
    "CFG_MSGOUT_UBX_MON_RF_UART1": (0x2091035A, U1),
    "CFG_MSGOUT_UBX_MON_RF_UART2": (0x2091035B, U1),
    "CFG_MSGOUT_UBX_MON_RF_USB": (0x2091035C, U1),
    "CFG_MSGOUT_UBX_MON_RXBUF_I2C": (0x209101A0, U1),
    "CFG_MSGOUT_UBX_MON_RXBUF_SPI": (0x209101A4, U1),
    "CFG_MSGOUT_UBX_MON_RXBUF_UART1": (0x209101A1, U1),
    "CFG_MSGOUT_UBX_MON_RXBUF_UART2": (0x209101A2, U1),
    "CFG_MSGOUT_UBX_MON_RXBUF_USB": (0x209101A3, U1),
    "CFG_MSGOUT_UBX_MON_RXR_I2C": (0x20910187, U1),
    "CFG_MSGOUT_UBX_MON_RXR_SPI": (0x2091018B, U1),
    "CFG_MSGOUT_UBX_MON_RXR_UART1": (0x20910188, U1),
    "CFG_MSGOUT_UBX_MON_RXR_UART2": (0x20910189, U1),
    "CFG_MSGOUT_UBX_MON_RXR_USB": (0x2091018A, U1),
    "CFG_MSGOUT_UBX_MON_SPAN_I2C": (0x2091038B, U1),
    "CFG_MSGOUT_UBX_MON_SPAN_SPI": (0x2091038F, U1),
    "CFG_MSGOUT_UBX_MON_SPAN_UART1": (0x2091038C, U1),
    "CFG_MSGOUT_UBX_MON_SPAN_UART2": (0x2091038D, U1),
    "CFG_MSGOUT_UBX_MON_SPAN_USB": (0x2091038E, U1),
    "CFG_MSGOUT_UBX_MON_SYS_I2C": (0x2091069D, U1),
    "CFG_MSGOUT_UBX_MON_SYS_SPI": (0x209106A1, U1),
    "CFG_MSGOUT_UBX_MON_SYS_UART1": (0x2091069E, U1),
    "CFG_MSGOUT_UBX_MON_SYS_UART2": (0x2091069F, U1),
    "CFG_MSGOUT_UBX_MON_SYS_USB": (0x209106A0, U1),
    "CFG_MSGOUT_UBX_MON_TXBUF_I2C": (0x2091019B, U1),
    "CFG_MSGOUT_UBX_MON_TXBUF_SPI": (0x2091019F, U1),
    "CFG_MSGOUT_UBX_MON_TXBUF_UART1": (0x2091019C, U1),
    "CFG_MSGOUT_UBX_MON_TXBUF_UART2": (0x2091019D, U1),
    "CFG_MSGOUT_UBX_MON_TXBUF_USB": (0x2091019E, U1),
    "CFG_MSGOUT_UBX_NAV_AOPSTATUS_I2C": (0x20910079, U1),
    "CFG_MSGOUT_UBX_NAV_AOPSTATUS_SPI": (0x2091007D, U1),
    "CFG_MSGOUT_UBX_NAV_AOPSTATUS_UART1": (0x2091007A, U1),
    "CFG_MSGOUT_UBX_NAV_AOPSTATUS_UART2": (0x2091007B, U1),
    "CFG_MSGOUT_UBX_NAV_AOPSTATUS_USB": (0x2091007C, U1),
    "CFG_MSGOUT_UBX_NAV_ATT_I2C": (0x2091001F, U1),
    "CFG_MSGOUT_UBX_NAV_ATT_SPI": (0x20910023, U1),
    "CFG_MSGOUT_UBX_NAV_ATT_UART1": (0x20910020, U1),
    "CFG_MSGOUT_UBX_NAV_ATT_UART2": (0x20910021, U1),
    "CFG_MSGOUT_UBX_NAV_ATT_USB": (0x20910022, U1),
    "CFG_MSGOUT_UBX_NAV_CLOCK_I2C": (0x20910065, U1),
    "CFG_MSGOUT_UBX_NAV_CLOCK_SPI": (0x20910069, U1),
    "CFG_MSGOUT_UBX_NAV_CLOCK_UART1": (0x20910066, U1),
    "CFG_MSGOUT_UBX_NAV_CLOCK_UART2": (0x20910067, U1),
    "CFG_MSGOUT_UBX_NAV_CLOCK_USB": (0x20910068, U1),
    "CFG_MSGOUT_UBX_NAV_COV_I2C": (0x20910083, U1),
    "CFG_MSGOUT_UBX_NAV_COV_SPI": (0x20910087, U1),
    "CFG_MSGOUT_UBX_NAV_COV_UART1": (0x20910084, U1),
    "CFG_MSGOUT_UBX_NAV_COV_UART2": (0x20910085, U1),
    "CFG_MSGOUT_UBX_NAV_COV_USB": (0x20910086, U1),
    "CFG_MSGOUT_UBX_NAV_DGPS_I2C": (0x20910074, U1),
    "CFG_MSGOUT_UBX_NAV_DGPS_SPI": (0x20910078, U1),
    "CFG_MSGOUT_UBX_NAV_DGPS_UART1": (0x20910075, U1),
    "CFG_MSGOUT_UBX_NAV_DGPS_UART2": (0x20910076, U1),
    "CFG_MSGOUT_UBX_NAV_DGPS_USB": (0x20910077, U1),
    "CFG_MSGOUT_UBX_NAV_DOP_I2C": (0x20910038, U1),
    "CFG_MSGOUT_UBX_NAV_DOP_SPI": (0x2091003C, U1),
    "CFG_MSGOUT_UBX_NAV_DOP_UART1": (0x20910039, U1),
    "CFG_MSGOUT_UBX_NAV_DOP_UART2": (0x2091003A, U1),
    "CFG_MSGOUT_UBX_NAV_DOP_USB": (0x2091003B, U1),
    "CFG_MSGOUT_UBX_NAV_EELL_I2C": (0x20910313, U1),
    "CFG_MSGOUT_UBX_NAV_EELL_SPI": (0x20910317, U1),
    "CFG_MSGOUT_UBX_NAV_EELL_UART1": (0x20910314, U1),
    "CFG_MSGOUT_UBX_NAV_EELL_UART2": (0x20910315, U1),
    "CFG_MSGOUT_UBX_NAV_EELL_USB": (0x20910316, U1),
    "CFG_MSGOUT_UBX_NAV_EOE_I2C": (0x2091015F, U1),
    "CFG_MSGOUT_UBX_NAV_EOE_SPI": (0x20910163, U1),
    "CFG_MSGOUT_UBX_NAV_EOE_UART1": (0x20910160, U1),
    "CFG_MSGOUT_UBX_NAV_EOE_UART2": (0x20910161, U1),
    "CFG_MSGOUT_UBX_NAV_EOE_USB": (0x20910162, U1),
    "CFG_MSGOUT_UBX_NAV_GEOFENCE_I2C": (0x209100A1, U1),
    "CFG_MSGOUT_UBX_NAV_GEOFENCE_SPI": (0x209100A5, U1),
    "CFG_MSGOUT_UBX_NAV_GEOFENCE_UART1": (0x209100A2, U1),
    "CFG_MSGOUT_UBX_NAV_GEOFENCE_UART2": (0x209100A3, U1),
    "CFG_MSGOUT_UBX_NAV_GEOFENCE_USB": (0x209100A4, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSECEF_I2C": (0x2091002E, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSECEF_SPI": (0x20910032, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSECEF_UART1": (0x2091002F, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSECEF_UART2": (0x20910030, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSECEF_USB": (0x20910031, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSLLH_I2C": (0x20910033, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSLLH_SPI": (0x20910037, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSLLH_UART1": (0x20910034, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSLLH_UART2": (0x20910035, U1),
    "CFG_MSGOUT_UBX_NAV_HPPOSLLH_USB": (0x20910036, U1),
    "CFG_MSGOUT_UBX_NAV_NMI_I2C": (0x20910590, U1),
    "CFG_MSGOUT_UBX_NAV_NMI_SPI": (0x20910594, U1),
    "CFG_MSGOUT_UBX_NAV_NMI_UART1": (0x20910591, U1),
    "CFG_MSGOUT_UBX_NAV_NMI_UART2": (0x20910592, U1),
    "CFG_MSGOUT_UBX_NAV_NMI_USB": (0x20910593, U1),
    "CFG_MSGOUT_UBX_NAV_ODO_I2C": (0x2091007E, U1),
    "CFG_MSGOUT_UBX_NAV_ODO_SPI": (0x20910082, U1),
    "CFG_MSGOUT_UBX_NAV_ODO_UART1": (0x2091007F, U1),
    "CFG_MSGOUT_UBX_NAV_ODO_UART2": (0x20910080, U1),
    "CFG_MSGOUT_UBX_NAV_ODO_USB": (0x20910081, U1),
    "CFG_MSGOUT_UBX_NAV_ORB_I2C": (0x20910010, U1),
    "CFG_MSGOUT_UBX_NAV_ORB_SPI": (0x20910014, U1),
    "CFG_MSGOUT_UBX_NAV_ORB_UART1": (0x20910011, U1),
    "CFG_MSGOUT_UBX_NAV_ORB_UART2": (0x20910012, U1),
    "CFG_MSGOUT_UBX_NAV_ORB_USB": (0x20910013, U1),
    "CFG_MSGOUT_UBX_NAV_PL_I2C": (0x20910415, U1),
    "CFG_MSGOUT_UBX_NAV_PL_SPI": (0x20910419, U1),
    "CFG_MSGOUT_UBX_NAV_PL_UART1": (0x20910416, U1),
    "CFG_MSGOUT_UBX_NAV_PL_UART2": (0x20910417, U1),
    "CFG_MSGOUT_UBX_NAV_PL_USB": (0x20910418, U1),
    "CFG_MSGOUT_UBX_NAV_POSECEF_I2C": (0x20910024, U1),
    "CFG_MSGOUT_UBX_NAV_POSECEF_SPI": (0x20910028, U1),
    "CFG_MSGOUT_UBX_NAV_POSECEF_UART1": (0x20910025, U1),
    "CFG_MSGOUT_UBX_NAV_POSECEF_UART2": (0x20910026, U1),
    "CFG_MSGOUT_UBX_NAV_POSECEF_USB": (0x20910027, U1),
    "CFG_MSGOUT_UBX_NAV_POSLLH_I2C": (0x20910029, U1),
    "CFG_MSGOUT_UBX_NAV_POSLLH_SPI": (0x2091002D, U1),
    "CFG_MSGOUT_UBX_NAV_POSLLH_UART1": (0x2091002A, U1),
    "CFG_MSGOUT_UBX_NAV_POSLLH_UART2": (0x2091002B, U1),
    "CFG_MSGOUT_UBX_NAV_POSLLH_USB": (0x2091002C, U1),
    "CFG_MSGOUT_UBX_NAV_PVAT_I2C": (0x2091062A, U1),
    "CFG_MSGOUT_UBX_NAV_PVAT_SPI": (0x2091062E, U1),
    "CFG_MSGOUT_UBX_NAV_PVAT_UART1": (0x2091062B, U1),
    "CFG_MSGOUT_UBX_NAV_PVAT_UART2": (0x2091062C, U1),
    "CFG_MSGOUT_UBX_NAV_PVAT_USB": (0x2091062D, U1),
    "CFG_MSGOUT_UBX_NAV_PVT_I2C": (0x20910006, U1),
    "CFG_MSGOUT_UBX_NAV_PVT_SPI": (0x2091000A, U1),
    "CFG_MSGOUT_UBX_NAV_PVT_UART1": (0x20910007, U1),
    "CFG_MSGOUT_UBX_NAV_PVT_UART2": (0x20910008, U1),
    "CFG_MSGOUT_UBX_NAV_PVT_USB": (0x20910009, U1),
    "CFG_MSGOUT_UBX_NAV_RELPOSNED_I2C": (0x2091008D, U1),
    "CFG_MSGOUT_UBX_NAV_RELPOSNED_SPI": (0x20910091, U1),
    "CFG_MSGOUT_UBX_NAV_RELPOSNED_UART1": (0x2091008E, U1),
    "CFG_MSGOUT_UBX_NAV_RELPOSNED_UART2": (0x2091008F, U1),
    "CFG_MSGOUT_UBX_NAV_RELPOSNED_USB": (0x20910090, U1),
    "CFG_MSGOUT_UBX_NAV_SAT_I2C": (0x20910015, U1),
    "CFG_MSGOUT_UBX_NAV_SAT_SPI": (0x20910019, U1),
    "CFG_MSGOUT_UBX_NAV_SAT_UART1": (0x20910016, U1),
    "CFG_MSGOUT_UBX_NAV_SAT_UART2": (0x20910017, U1),
    "CFG_MSGOUT_UBX_NAV_SAT_USB": (0x20910018, U1),
    "CFG_MSGOUT_UBX_NAV_SBAS_I2C": (0x2091006A, U1),
    "CFG_MSGOUT_UBX_NAV_SBAS_SPI": (0x2091006E, U1),
    "CFG_MSGOUT_UBX_NAV_SBAS_UART1": (0x2091006B, U1),
    "CFG_MSGOUT_UBX_NAV_SBAS_UART2": (0x2091006C, U1),
    "CFG_MSGOUT_UBX_NAV_SBAS_USB": (0x2091006D, U1),
    "CFG_MSGOUT_UBX_NAV_SIG_I2C": (0x20910345, U1),
    "CFG_MSGOUT_UBX_NAV_SIG_SPI": (0x20910349, U1),
    "CFG_MSGOUT_UBX_NAV_SIG_UART1": (0x20910346, U1),
    "CFG_MSGOUT_UBX_NAV_SIG_UART2": (0x20910347, U1),
    "CFG_MSGOUT_UBX_NAV_SIG_USB": (0x20910348, U1),
    "CFG_MSGOUT_UBX_NAV_SLAS_I2C": (0x20910336, U1),
    "CFG_MSGOUT_UBX_NAV_SLAS_SPI": (0x2091033A, U1),
    "CFG_MSGOUT_UBX_NAV_SLAS_UART1": (0x20910337, U1),
    "CFG_MSGOUT_UBX_NAV_SLAS_UART2": (0x20910338, U1),
    "CFG_MSGOUT_UBX_NAV_SLAS_USB": (0x20910339, U1),
    "CFG_MSGOUT_UBX_NAV_SOL_I2C": (0x20910001, U1),
    "CFG_MSGOUT_UBX_NAV_SOL_SPI": (0x20910005, U1),
    "CFG_MSGOUT_UBX_NAV_SOL_UART1": (0x20910002, U1),
    "CFG_MSGOUT_UBX_NAV_SOL_UART2": (0x20910003, U1),
    "CFG_MSGOUT_UBX_NAV_SOL_USB": (0x20910004, U1),
    "CFG_MSGOUT_UBX_NAV_STATUS_I2C": (0x2091001A, U1),
    "CFG_MSGOUT_UBX_NAV_STATUS_SPI": (0x2091001E, U1),
    "CFG_MSGOUT_UBX_NAV_STATUS_UART1": (0x2091001B, U1),
    "CFG_MSGOUT_UBX_NAV_STATUS_UART2": (0x2091001C, U1),
    "CFG_MSGOUT_UBX_NAV_STATUS_USB": (0x2091001D, U1),
    "CFG_MSGOUT_UBX_NAV_SVIN_I2C": (0x20910088, U1),
    "CFG_MSGOUT_UBX_NAV_SVIN_SPI": (0x2091008C, U1),
    "CFG_MSGOUT_UBX_NAV_SVIN_UART1": (0x20910089, U1),
    "CFG_MSGOUT_UBX_NAV_SVIN_UART2": (0x2091008A, U1),
    "CFG_MSGOUT_UBX_NAV_SVIN_USB": (0x2091008B, U1),
    "CFG_MSGOUT_UBX_NAV_SVINFO_I2C": (0x2091000B, U1),
    "CFG_MSGOUT_UBX_NAV_SVINFO_SPI": (0x2091000F, U1),
    "CFG_MSGOUT_UBX_NAV_SVINFO_UART1": (0x2091000C, U1),
    "CFG_MSGOUT_UBX_NAV_SVINFO_UART2": (0x2091000D, U1),
    "CFG_MSGOUT_UBX_NAV_SVINFO_USB": (0x2091000E, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEBDS_I2C": (0x20910051, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEBDS_SPI": (0x20910055, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEBDS_UART1": (0x20910052, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEBDS_UART2": (0x20910053, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEBDS_USB": (0x20910054, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGAL_I2C": (0x20910056, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGAL_SPI": (0x2091005A, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGAL_UART1": (0x20910057, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGAL_UART2": (0x20910058, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGAL_USB": (0x20910059, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGLO_I2C": (0x2091004C, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGLO_SPI": (0x20910050, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGLO_UART1": (0x2091004D, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGLO_UART2": (0x2091004E, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGLO_USB": (0x2091004F, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGPS_I2C": (0x20910047, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGPS_SPI": (0x2091004B, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGPS_UART1": (0x20910048, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGPS_UART2": (0x20910049, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEGPS_USB": (0x2091004A, U1),
    "CFG_MSGOUT_UBX_NAV_TIMELS_I2C": (0x20910060, U1),
    "CFG_MSGOUT_UBX_NAV_TIMELS_SPI": (0x20910064, U1),
    "CFG_MSGOUT_UBX_NAV_TIMELS_UART1": (0x20910061, U1),
    "CFG_MSGOUT_UBX_NAV_TIMELS_UART2": (0x20910062, U1),
    "CFG_MSGOUT_UBX_NAV_TIMELS_USB": (0x20910063, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEQZSS_I2C": (0x20910386, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEQZSS_SPI": (0x2091038A, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEQZSS_UART1": (0x20910387, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEQZSS_UART2": (0x20910388, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEQZSS_USB": (0x20910389, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEUTC_I2C": (0x2091005B, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEUTC_SPI": (0x2091005F, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEUTC_UART1": (0x2091005C, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEUTC_UART2": (0x2091005D, U1),
    "CFG_MSGOUT_UBX_NAV_TIMEUTC_USB": (0x2091005E, U1),
    "CFG_MSGOUT_UBX_NAV_VELECEF_I2C": (0x2091003D, U1),
    "CFG_MSGOUT_UBX_NAV_VELECEF_SPI": (0x20910041, U1),
    "CFG_MSGOUT_UBX_NAV_VELECEF_UART1": (0x2091003E, U1),
    "CFG_MSGOUT_UBX_NAV_VELECEF_UART2": (0x2091003F, U1),
    "CFG_MSGOUT_UBX_NAV_VELECEF_USB": (0x20910040, U1),
    "CFG_MSGOUT_UBX_NAV_VELNED_I2C": (0x20910042, U1),
    "CFG_MSGOUT_UBX_NAV_VELNED_SPI": (0x20910046, U1),
    "CFG_MSGOUT_UBX_NAV_VELNED_UART1": (0x20910043, U1),
    "CFG_MSGOUT_UBX_NAV_VELNED_UART2": (0x20910044, U1),
    "CFG_MSGOUT_UBX_NAV_VELNED_USB": (0x20910045, U1),
    "CFG_MSGOUT_UBX_NAV2_CLOCK_I2C": (0x20910430, U1),
    "CFG_MSGOUT_UBX_NAV2_CLOCK_SPI": (0x20910434, U1),
    "CFG_MSGOUT_UBX_NAV2_CLOCK_UART1": (0x20910431, U1),
    "CFG_MSGOUT_UBX_NAV2_CLOCK_UART2": (0x20910432, U1),
    "CFG_MSGOUT_UBX_NAV2_CLOCK_USB": (0x20910433, U1),
    "CFG_MSGOUT_UBX_NAV2_COV_I2C": (0x20910435, U1),
    "CFG_MSGOUT_UBX_NAV2_COV_SPI": (0x20910439, U1),
    "CFG_MSGOUT_UBX_NAV2_COV_UART1": (0x20910436, U1),
    "CFG_MSGOUT_UBX_NAV2_COV_UART2": (0x20910437, U1),
    "CFG_MSGOUT_UBX_NAV2_COV_USB": (0x20910438, U1),
    "CFG_MSGOUT_UBX_NAV2_DOP_I2C": (0x20910465, U1),
    "CFG_MSGOUT_UBX_NAV2_DOP_SPI": (0x20910469, U1),
    "CFG_MSGOUT_UBX_NAV2_DOP_UART1": (0x20910466, U1),
    "CFG_MSGOUT_UBX_NAV2_DOP_UART2": (0x20910467, U1),
    "CFG_MSGOUT_UBX_NAV2_DOP_USB": (0x20910468, U1),
    "CFG_MSGOUT_UBX_NAV2_EELL_I2C": (0x20910470, U1),
    "CFG_MSGOUT_UBX_NAV2_EELL_SPI": (0x20910474, U1),
    "CFG_MSGOUT_UBX_NAV2_EELL_UART1": (0x20910471, U1),
    "CFG_MSGOUT_UBX_NAV2_EELL_UART2": (0x20910472, U1),
    "CFG_MSGOUT_UBX_NAV2_EELL_USB": (0x20910473, U1),
    "CFG_MSGOUT_UBX_NAV2_EOE_I2C": (0x20910565, U1),
    "CFG_MSGOUT_UBX_NAV2_EOE_SPI": (0x20910569, U1),
    "CFG_MSGOUT_UBX_NAV2_EOE_UART1": (0x20910566, U1),
    "CFG_MSGOUT_UBX_NAV2_EOE_UART2": (0x20910567, U1),
    "CFG_MSGOUT_UBX_NAV2_EOE_USB": (0x20910568, U1),
    "CFG_MSGOUT_UBX_NAV2_ODO_I2C": (0x20910475, U1),
    "CFG_MSGOUT_UBX_NAV2_ODO_SPI": (0x20910479, U1),
    "CFG_MSGOUT_UBX_NAV2_ODO_UART1": (0x20910476, U1),
    "CFG_MSGOUT_UBX_NAV2_ODO_UART2": (0x20910477, U1),
    "CFG_MSGOUT_UBX_NAV2_ODO_USB": (0x20910478, U1),
    "CFG_MSGOUT_UBX_NAV2_POSECEF_I2C": (0x20910480, U1),
    "CFG_MSGOUT_UBX_NAV2_POSECEF_SPI": (0x20910484, U1),
    "CFG_MSGOUT_UBX_NAV2_POSECEF_UART1": (0x20910481, U1),
    "CFG_MSGOUT_UBX_NAV2_POSECEF_UART2": (0x20910482, U1),
    "CFG_MSGOUT_UBX_NAV2_POSECEF_USB": (0x20910483, U1),
    "CFG_MSGOUT_UBX_NAV2_POSLLH_I2C": (0x20910485, U1),
    "CFG_MSGOUT_UBX_NAV2_POSLLH_SPI": (0x20910489, U1),
    "CFG_MSGOUT_UBX_NAV2_POSLLH_UART1": (0x20910486, U1),
    "CFG_MSGOUT_UBX_NAV2_POSLLH_UART2": (0x20910487, U1),
    "CFG_MSGOUT_UBX_NAV2_POSLLH_USB": (0x20910488, U1),
    "CFG_MSGOUT_UBX_NAV2_PVAT_I2C": (0x2091062F, U1),
    "CFG_MSGOUT_UBX_NAV2_PVAT_SPI": (0x20910633, U1),
    "CFG_MSGOUT_UBX_NAV2_PVAT_UART1": (0x20910630, U1),
    "CFG_MSGOUT_UBX_NAV2_PVAT_UART2": (0x20910631, U1),
    "CFG_MSGOUT_UBX_NAV2_PVAT_USB": (0x20910632, U1),
    "CFG_MSGOUT_UBX_NAV2_PVT_I2C": (0x20910490, U1),
    "CFG_MSGOUT_UBX_NAV2_PVT_SPI": (0x20910494, U1),
    "CFG_MSGOUT_UBX_NAV2_PVT_UART1": (0x20910491, U1),
    "CFG_MSGOUT_UBX_NAV2_PVT_UART2": (0x20910492, U1),
    "CFG_MSGOUT_UBX_NAV2_PVT_USB": (0x20910493, U1),
    "CFG_MSGOUT_UBX_NAV2_SAT_I2C": (0x20910495, U1),
    "CFG_MSGOUT_UBX_NAV2_SAT_SPI": (0x20910499, U1),
    "CFG_MSGOUT_UBX_NAV2_SAT_UART1": (0x20910496, U1),
    "CFG_MSGOUT_UBX_NAV2_SAT_UART2": (0x20910497, U1),
    "CFG_MSGOUT_UBX_NAV2_SAT_USB": (0x20910498, U1),
    "CFG_MSGOUT_UBX_NAV2_SBAS_I2C": (0x20910500, U1),
    "CFG_MSGOUT_UBX_NAV2_SBAS_SPI": (0x20910504, U1),
    "CFG_MSGOUT_UBX_NAV2_SBAS_UART1": (0x20910501, U1),
    "CFG_MSGOUT_UBX_NAV2_SBAS_UART2": (0x20910502, U1),
    "CFG_MSGOUT_UBX_NAV2_SBAS_USB": (0x20910503, U1),
    "CFG_MSGOUT_UBX_NAV2_SIG_I2C": (0x20910505, U1),
    "CFG_MSGOUT_UBX_NAV2_SIG_SPI": (0x20910509, U1),
    "CFG_MSGOUT_UBX_NAV2_SIG_UART1": (0x20910506, U1),
    "CFG_MSGOUT_UBX_NAV2_SIG_UART2": (0x20910507, U1),
    "CFG_MSGOUT_UBX_NAV2_SIG_USB": (0x20910508, U1),
    "CFG_MSGOUT_UBX_NAV2_SLAS_I2C": (0x20910510, U1),
    "CFG_MSGOUT_UBX_NAV2_SLAS_SPI": (0x20910514, U1),
    "CFG_MSGOUT_UBX_NAV2_SLAS_UART1": (0x20910511, U1),
    "CFG_MSGOUT_UBX_NAV2_SLAS_UART2": (0x20910512, U1),
    "CFG_MSGOUT_UBX_NAV2_SLAS_USB": (0x20910513, U1),
    "CFG_MSGOUT_UBX_NAV2_STATUS_I2C": (0x20910515, U1),
    "CFG_MSGOUT_UBX_NAV2_STATUS_SPI": (0x20910519, U1),
    "CFG_MSGOUT_UBX_NAV2_STATUS_UART1": (0x20910516, U1),
    "CFG_MSGOUT_UBX_NAV2_STATUS_UART2": (0x20910517, U1),
    "CFG_MSGOUT_UBX_NAV2_STATUS_USB": (0x20910518, U1),
    "CFG_MSGOUT_UBX_NAV2_SVIN_I2C": (0x20910520, U1),
    "CFG_MSGOUT_UBX_NAV2_SVIN_SPI": (0x20910524, U1),
    "CFG_MSGOUT_UBX_NAV2_SVIN_UART1": (0x20910521, U1),
    "CFG_MSGOUT_UBX_NAV2_SVIN_UART2": (0x20910522, U1),
    "CFG_MSGOUT_UBX_NAV2_SVIN_USB": (0x20910523, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEBDS_I2C": (0x20910525, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEBDS_SPI": (0x20910529, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEBDS_UART1": (0x20910526, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEBDS_UART2": (0x20910527, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEBDS_USB": (0x20910528, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGAL_I2C": (0x20910530, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGAL_SPI": (0x20910534, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGAL_UART1": (0x20910531, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGAL_UART2": (0x20910532, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGAL_USB": (0x20910533, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGLO_I2C": (0x20910535, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGLO_SPI": (0x20910539, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGLO_UART1": (0x20910536, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGLO_UART2": (0x20910537, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGLO_USB": (0x20910538, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGPS_I2C": (0x20910540, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGPS_SPI": (0x20910544, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGPS_UART1": (0x20910541, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGPS_UART2": (0x20910542, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEGPS_USB": (0x20910543, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMELS_I2C": (0x20910545, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMELS_SPI": (0x20910549, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMELS_UART1": (0x20910546, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMELS_UART2": (0x20910547, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMELS_USB": (0x20910548, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_I2C": (0x20910575, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_SPI": (0x20910579, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_UART1": (0x20910576, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_UART2": (0x20910577, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_USB": (0x20910578, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEUTC_I2C": (0x20910550, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEUTC_SPI": (0x20910554, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEUTC_UART1": (0x20910551, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEUTC_UART2": (0x20910552, U1),
    "CFG_MSGOUT_UBX_NAV2_TIMEUTC_USB": (0x20910553, U1),
    "CFG_MSGOUT_UBX_NAV2_VELECEF_I2C": (0x20910555, U1),
    "CFG_MSGOUT_UBX_NAV2_VELECEF_SPI": (0x20910559, U1),
    "CFG_MSGOUT_UBX_NAV2_VELECEF_UART1": (0x20910556, U1),
    "CFG_MSGOUT_UBX_NAV2_VELECEF_UART2": (0x20910557, U1),
    "CFG_MSGOUT_UBX_NAV2_VELECEF_USB": (0x20910558, U1),
    "CFG_MSGOUT_UBX_NAV2_VELNED_I2C": (0x20910560, U1),
    "CFG_MSGOUT_UBX_NAV2_VELNED_SPI": (0x20910564, U1),
    "CFG_MSGOUT_UBX_NAV2_VELNED_UART1": (0x20910561, U1),
    "CFG_MSGOUT_UBX_NAV2_VELNED_UART2": (0x20910562, U1),
    "CFG_MSGOUT_UBX_NAV2_VELNED_USB": (0x20910563, U1),
    "CFG_MSGOUT_UBX_RXM_ALM_I2C": (0x20910173, U1),
    "CFG_MSGOUT_UBX_RXM_ALM_SPI": (0x20910177, U1),
    "CFG_MSGOUT_UBX_RXM_ALM_UART1": (0x20910174, U1),
    "CFG_MSGOUT_UBX_RXM_ALM_UART2": (0x20910175, U1),
    "CFG_MSGOUT_UBX_RXM_ALM_USB": (0x20910176, U1),
    "CFG_MSGOUT_UBX_RXM_COR_I2C": (0x209106B6, U1),
    "CFG_MSGOUT_UBX_RXM_COR_SPI": (0x209106BA, U1),
    "CFG_MSGOUT_UBX_RXM_COR_UART1": (0x209106B7, U1),
    "CFG_MSGOUT_UBX_RXM_COR_UART2": (0x209106B8, U1),
    "CFG_MSGOUT_UBX_RXM_COR_USB": (0x209106B9, U1),
    "CFG_MSGOUT_UBX_RXM_EPH_I2C": (0x20910169, U1),
    "CFG_MSGOUT_UBX_RXM_EPH_SPI": (0x2091016D, U1),
    "CFG_MSGOUT_UBX_RXM_EPH_UART1": (0x2091016A, U1),
    "CFG_MSGOUT_UBX_RXM_EPH_UART2": (0x2091016B, U1),
    "CFG_MSGOUT_UBX_RXM_EPH_USB": (0x2091016C, U1),
    "CFG_MSGOUT_UBX_RXM_IMES_I2C": (0x2091015A, U1),
    "CFG_MSGOUT_UBX_RXM_IMES_SPI": (0x2091015E, U1),
    "CFG_MSGOUT_UBX_RXM_IMES_UART1": (0x2091015B, U1),
    "CFG_MSGOUT_UBX_RXM_IMES_UART2": (0x2091015C, U1),
    "CFG_MSGOUT_UBX_RXM_IMES_USB": (0x2091015D, U1),
    "CFG_MSGOUT_UBX_RXM_MEASX_I2C": (0x20910204, U1),
    "CFG_MSGOUT_UBX_RXM_MEASX_SPI": (0x20910208, U1),
    "CFG_MSGOUT_UBX_RXM_MEASX_UART1": (0x20910205, U1),
    "CFG_MSGOUT_UBX_RXM_MEASX_UART2": (0x20910206, U1),
    "CFG_MSGOUT_UBX_RXM_MEASX_USB": (0x20910207, U1),
    "CFG_MSGOUT_UBX_RXM_PMP_I2C": (0x2091031D, U1),
    "CFG_MSGOUT_UBX_RXM_PMP_SPI": (0x20910321, U1),
    "CFG_MSGOUT_UBX_RXM_PMP_UART1": (0x2091031E, U1),
    "CFG_MSGOUT_UBX_RXM_PMP_UART2": (0x2091031F, U1),
    "CFG_MSGOUT_UBX_RXM_PMP_USB": (0x20910320, U1),
    "CFG_MSGOUT_UBX_RXM_QZSSL6_I2C": (0x2091033F, U1),
    "CFG_MSGOUT_UBX_RXM_QZSSL6_SPI": (0x20910343, U1),
    "CFG_MSGOUT_UBX_RXM_QZSSL6_UART1": (0x20910340, U1),
    "CFG_MSGOUT_UBX_RXM_QZSSL6_UART2": (0x20910341, U1),
    "CFG_MSGOUT_UBX_RXM_QZSSL6_USB": (0x20910342, U1),
    "CFG_MSGOUT_UBX_RXM_RAWX_I2C": (0x209102A4, U1),
    "CFG_MSGOUT_UBX_RXM_RAWX_SPI": (0x209102A8, U1),
    "CFG_MSGOUT_UBX_RXM_RAWX_UART1": (0x209102A5, U1),
    "CFG_MSGOUT_UBX_RXM_RAWX_UART2": (0x209102A6, U1),
    "CFG_MSGOUT_UBX_RXM_RAWX_USB": (0x209102A7, U1),
    "CFG_MSGOUT_UBX_RXM_RLM_I2C": (0x2091025E, U1),
    "CFG_MSGOUT_UBX_RXM_RLM_SPI": (0x20910262, U1),
    "CFG_MSGOUT_UBX_RXM_RLM_UART1": (0x2091025F, U1),
    "CFG_MSGOUT_UBX_RXM_RLM_UART2": (0x20910260, U1),
    "CFG_MSGOUT_UBX_RXM_RLM_USB": (0x20910261, U1),
    "CFG_MSGOUT_UBX_RXM_RTCM_I2C": (0x20910268, U1),
    "CFG_MSGOUT_UBX_RXM_RTCM_SPI": (0x2091026C, U1),
    "CFG_MSGOUT_UBX_RXM_RTCM_UART1": (0x20910269, U1),
    "CFG_MSGOUT_UBX_RXM_RTCM_UART2": (0x2091026A, U1),
    "CFG_MSGOUT_UBX_RXM_RTCM_USB": (0x2091026B, U1),
    "CFG_MSGOUT_UBX_RXM_SFRBX_I2C": (0x20910231, U1),
    "CFG_MSGOUT_UBX_RXM_SFRBX_SPI": (0x20910235, U1),
    "CFG_MSGOUT_UBX_RXM_SFRBX_UART1": (0x20910232, U1),
    "CFG_MSGOUT_UBX_RXM_SFRBX_UART2": (0x20910233, U1),
    "CFG_MSGOUT_UBX_RXM_SFRBX_USB": (0x20910234, U1),
    "CFG_MSGOUT_UBX_RXM_SPARTN_I2C": (0x20910605, U1),
    "CFG_MSGOUT_UBX_RXM_SPARTN_SPI": (0x20910609, U1),
    "CFG_MSGOUT_UBX_RXM_SPARTN_UART1": (0x20910606, U1),
    "CFG_MSGOUT_UBX_RXM_SPARTN_UART2": (0x20910607, U1),
    "CFG_MSGOUT_UBX_RXM_SPARTN_USB": (0x20910608, U1),
    "CFG_MSGOUT_UBX_RXM_SVSI_I2C": (0x20910150, U1),
    "CFG_MSGOUT_UBX_RXM_SVSI_SPI": (0x20910154, U1),
    "CFG_MSGOUT_UBX_RXM_SVSI_UART1": (0x20910151, U1),
    "CFG_MSGOUT_UBX_RXM_SVSI_UART2": (0x20910152, U1),
    "CFG_MSGOUT_UBX_RXM_SVSI_USB": (0x20910153, U1),
    "CFG_MSGOUT_UBX_RXM_TM_I2C": (0x20910610, U1),
    "CFG_MSGOUT_UBX_RXM_TM_SPI": (0x20910614, U1),
    "CFG_MSGOUT_UBX_RXM_TM_UART1": (0x20910611, U1),
    "CFG_MSGOUT_UBX_RXM_TM_UART2": (0x20910612, U1),
    "CFG_MSGOUT_UBX_RXM_TM_USB": (0x20910613, U1),
    "CFG_MSGOUT_UBX_SEC_ECSIGN_I2C": (0x2091034A, U1),
    "CFG_MSGOUT_UBX_SEC_ECSIGN_SPI": (0x2091034E, U1),
    "CFG_MSGOUT_UBX_SEC_ECSIGN_UART1": (0x2091034B, U1),
    "CFG_MSGOUT_UBX_SEC_ECSIGN_UART2": (0x2091034C, U1),
    "CFG_MSGOUT_UBX_SEC_ECSIGN_USB": (0x2091034D, U1),
    "CFG_MSGOUT_UBX_SEC_SIG_I2C": (0x20910634, U1),
    "CFG_MSGOUT_UBX_SEC_SIG_SPI": (0x20910638, U1),
    "CFG_MSGOUT_UBX_SEC_SIG_UART1": (0x20910635, U1),
    "CFG_MSGOUT_UBX_SEC_SIG_UART2": (0x20910636, U1),
    "CFG_MSGOUT_UBX_SEC_SIG_USB": (0x20910637, U1),
    "CFG_MSGOUT_UBX_SEC_SIGLOG_I2C": (0x20910689, U1),
    "CFG_MSGOUT_UBX_SEC_SIGLOG_SPI": (0x2091068D, U1),
    "CFG_MSGOUT_UBX_SEC_SIGLOG_UART1": (0x2091068A, U1),
    "CFG_MSGOUT_UBX_SEC_SIGLOG_UART2": (0x2091068B, U1),
    "CFG_MSGOUT_UBX_SEC_SIGLOG_USB": (0x2091068C, U1),
    "CFG_MSGOUT_UBX_TIM_SVIN_I2C": (0x20910097, U1),
    "CFG_MSGOUT_UBX_TIM_SVIN_SPI": (0x2091009B, U1),
    "CFG_MSGOUT_UBX_TIM_SVIN_UART1": (0x20910098, U1),
    "CFG_MSGOUT_UBX_TIM_SVIN_UART2": (0x20910099, U1),
    "CFG_MSGOUT_UBX_TIM_SVIN_USB": (0x2091009A, U1),
    "CFG_MSGOUT_UBX_TIM_TM2_I2C": (0x20910178, U1),
    "CFG_MSGOUT_UBX_TIM_TM2_SPI": (0x2091017C, U1),
    "CFG_MSGOUT_UBX_TIM_TM2_UART1": (0x20910179, U1),
    "CFG_MSGOUT_UBX_TIM_TM2_UART2": (0x2091017A, U1),
    "CFG_MSGOUT_UBX_TIM_TM2_USB": (0x2091017B, U1),
    "CFG_MSGOUT_UBX_TIM_TP_I2C": (0x2091017D, U1),
    "CFG_MSGOUT_UBX_TIM_TP_SPI": (0x20910181, U1),
    "CFG_MSGOUT_UBX_TIM_TP_UART1": (0x2091017E, U1),
    "CFG_MSGOUT_UBX_TIM_TP_UART2": (0x2091017F, U1),
    "CFG_MSGOUT_UBX_TIM_TP_USB": (0x20910180, U1),
    "CFG_MSGOUT_UBX_TIM_VRFY_I2C": (0x20910092, U1),
    "CFG_MSGOUT_UBX_TIM_VRFY_SPI": (0x20910096, U1),
    "CFG_MSGOUT_UBX_TIM_VRFY_UART1": (0x20910093, U1),
    "CFG_MSGOUT_UBX_TIM_VRFY_UART2": (0x20910094, U1),
    "CFG_MSGOUT_UBX_TIM_VRFY_USB": (0x20910095, U1),
    "CFG_NAV2_OUT_ENABLED": (0x10170001, L),
    "CFG_NAV2_SBAS_USE_INTEGRITY": (0x10170002, L),
    "CFG_NAVHPG_DGNSSMODE": (0x20140011, E1),
    "CFG_NAVSPG_ACKAIDING": (0x10110025, L),
    "CFG_NAVSPG_CONSTR_ALT": (0x401100C1, I4),
    "CFG_NAVSPG_CONSTR_ALTVAR": (0x401100C2, U4),
    "CFG_NAVSPG_CONSTR_DGNSSTO": (0x201100C4, U1),
    "CFG_NAVSPG_CONSTR_PROPLIMIT": (0x401100C3, U4),
    "CFG_NAVSPG_DYNMODEL": (0x20110021, E1),
    "CFG_NAVSPG_FIXMODE": (0x20110011, E1),
    "CFG_NAVSPG_INFIL_CNOTHRS": (0x201100AB, U1),
    "CFG_NAVSPG_INFIL_MAXSVS": (0x201100A2, U1),
    "CFG_NAVSPG_INFIL_MINCNO": (0x201100A3, U1),
    "CFG_NAVSPG_INFIL_MINELEV": (0x201100A4, I1),
    "CFG_NAVSPG_INFIL_MINSVS": (0x201100A1, U1),
    "CFG_NAVSPG_INFIL_NCNOTHRS": (0x201100AA, U1),
    "CFG_NAVSPG_INIFIX3D": (0x10110013, L),
    "CFG_NAVSPG_OUTFIL_FACC": (0x301100B5, U2),
    "CFG_NAVSPG_OUTFIL_PACC": (0x301100B3, U2),
    "CFG_NAVSPG_OUTFIL_PDOP": (0x301100B1, U2),
    "CFG_NAVSPG_OUTFIL_TACC": (0x301100B4, U2),
    "CFG_NAVSPG_OUTFIL_TDOP": (0x301100B2, U2),
    "CFG_NAVSPG_PL_ENA": (0x101100D7, L),
    "CFG_NAVSPG_SIGATTCOMP": (0x201100D6, E1),
    "CFG_NAVSPG_USE_PPP": (0x10110019, L),
    "CFG_NAVSPG_USE_USRDAT": (0x10110061, L),
    "CFG_NAVSPG_USRDAT_DX": (0x40110064, R4),
    "CFG_NAVSPG_USRDAT_DY": (0x40110065, R4),
    "CFG_NAVSPG_USRDAT_DZ": (0x40110066, R4),
    "CFG_NAVSPG_USRDAT_FLAT": (0x50110063, R8),
    "CFG_NAVSPG_USRDAT_MAJA": (0x50110062, R8),
    "CFG_NAVSPG_USRDAT_ROTX": (0x40110067, R4),
    "CFG_NAVSPG_USRDAT_ROTY": (0x40110068, R4),
    "CFG_NAVSPG_USRDAT_ROTZ": (0x40110069, R4),
    "CFG_NAVSPG_USRDAT_SCALE": (0x4011006A, R4),
    "CFG_NAVSPG_UTCSTANDARD": (0x2011001C, E1),
    "CFG_NAVSPG_WKNROLLOVER": (0x30110017, U2),
    "CFG_NMEA_BDSTALKERID": (0x30930033, U2),
    "CFG_NMEA_COMPAT": (0x10930003, L),
    "CFG_NMEA_CONSIDER": (0x10930004, L),
    "CFG_NMEA_FILT_BDS": (0x10930017, L),
    "CFG_NMEA_FILT_GAL": (0x10930013, L),
    "CFG_NMEA_FILT_GLO": (0x10930016, L),
    "CFG_NMEA_FILT_GPS": (0x10930011, L),
    "CFG_NMEA_FILT_QZSS": (0x10930015, L),
    "CFG_NMEA_FILT_SBAS": (0x10930012, L),
    "CFG_NMEA_GSVTALKERID": (0x20930032, E1),
    "CFG_NMEA_HIGHPREC": (0x10930006, L),
    "CFG_NMEA_LIMIT82": (0x10930005, L),
    "CFG_NMEA_MAINTALKERID": (0x20930031, E1),
    "CFG_NMEA_MAXSVS": (0x20930002, E1),
    "CFG_NMEA_OUT_FROZENCOG": (0x10930026, L),
    "CFG_NMEA_OUT_INVDATE": (0x10930024, L),
    "CFG_NMEA_OUT_INVFIX": (0x10930021, L),
    "CFG_NMEA_OUT_INVTIME": (0x10930023, L),
    "CFG_NMEA_OUT_MSKFIX": (0x10930022, L),
    "CFG_NMEA_OUT_ONLYGPS": (0x10930025, L),
    "CFG_NMEA_PROTVER": (0x20930001, E1),
    "CFG_NMEA_SVNUMBERING": (0x20930007, E1),
    "CFG_ODO_COGLPGAIN": (0x20220032, U1),
    "CFG_ODO_COGMAXPOSACC": (0x20220022, U1),
    "CFG_ODO_COGMAXSPEED": (0x20220021, U1),
    "CFG_ODO_OUTLPCOG": (0x10220004, L),
    "CFG_ODO_OUTLPVEL": (0x10220003, L),
    "CFG_ODO_PROFILE": (0x20220005, E1),
    "CFG_ODO_USE_COG": (0x10220002, L),
    "CFG_ODO_USE_ODO": (0x10220001, L),
    "CFG_ODO_VELLPGAIN": (0x20220031, U1),
    "CFG_PM_ACQPERIOD": (0x40D00003, U4),
    "CFG_PM_DONOTENTEROFF": (0x10D00008, L),
    "CFG_PM_EXTINTBACKUP": (0x10D0000D, L),
    "CFG_PM_EXTINTINACTIVE": (0x10D0000E, L),
    "CFG_PM_EXTINTINACTIVITY": (0x40D0000F, U4),
    "CFG_PM_EXTINTSEL": (0x20D0000B, E1),
    "CFG_PM_EXTINTWAKE": (0x10D0000C, L),
    "CFG_PM_GRIDOFFSET": (0x40D00004, U4),
    "CFG_PM_LIMITPEAKCURR": (0x10D00010, L),
    "CFG_PM_MAXACQTIME": (0x20D00007, U1),
    "CFG_PM_MINACQTIME": (0x20D00006, U1),
    "CFG_PM_ONTIME": (0x30D00005, U2),
    "CFG_PM_OPERATEMODE": (0x20D00001, E1),
    "CFG_PM_POSUPDATEPERIOD": (0x40D00002, U4),
    "CFG_PM_UPDATEEPH": (0x10D0000A, L),
    "CFG_PM_WAITTIMEFIX": (0x10D00009, L),
    "CFG_PMP_CENTER_FREQUENCY": (0x40B10011, U4),
    "CFG_PMP_DATA_RATE": (0x30B10013, E2),
    "CFG_PMP_DESCRAMBLER_INIT": (0x30B10015, U2),
    "CFG_PMP_SEARCH_WINDOW": (0x30B10012, U2),
    "CFG_PMP_SERVICE_ID": (0x30B10017, U2),
    "CFG_PMP_UNIQUE_WORD": (0x50B1001A, U8),
    "CFG_PMP_USE_DESCRAMBLER": (0x10B10014, L),
    "CFG_PMP_USE_PRESCRAMBLING": (0x10B10019, L),
    "CFG_PMP_USE_SERVICE_ID": (0x10B10016, L),
    "CFG_QZSS_USE_SLAS_DGNSS": (0x10370005, L),
    "CFG_QZSS_USE_SLAS_RAIM_UNCORR": (0x10370007, L),
    "CFG_QZSS_USE_SLAS_TESTMODE": (0x10370006, L),
    "CFG_RATE_MEAS": (0x30210001, U2),
    "CFG_RATE_NAV_PRIO": (0x20210004, U1),
    "CFG_RATE_NAV": (0x30210002, U2),
    "CFG_RATE_TIMEREF": (0x20210003, E1),
    "CFG_RINV_BINARY": (0x10C70002, L),
    "CFG_RINV_CHUNK0": (0x50C70004, X8),
    "CFG_RINV_CHUNK1": (0x50C70005, X8),
    "CFG_RINV_CHUNK2": (0x50C70006, X8),
    "CFG_RINV_CHUNK3": (0x50C70007, X8),
    "CFG_RINV_DATA_SIZE": (0x20C70003, U1),
    "CFG_RINV_DUMP": (0x10C70001, L),
    "CFG_RTCM_DF003_IN_FILTER": (0x20090009, E1),
    "CFG_RTCM_DF003_IN": (0x30090008, U2),
    "CFG_RTCM_DF003_OUT": (0x30090001, U2),
    "CFG_SBAS_PRNSCANMASK": (0x50360006, X8),
    "CFG_SBAS_USE_DIFFCORR": (0x10360004, L),
    "CFG_SBAS_USE_INTEGRITY": (0x10360005, L),
    "CFG_SBAS_USE_RANGING": (0x10360003, L),
    "CFG_SBAS_USE_TESTMODE": (0x10360002, L),
    "CFG_SEC_CFG_LOCK_UNLOCKGRP1": (0x30F6000A, U2),
    "CFG_SEC_CFG_LOCK_UNLOCKGRP2": (0x30F6000B, U2),
    "CFG_SEC_CFG_LOCK": (0x10F60009, L),
    "CFG_SFCORE_HNR_RATE": (0x2008001A, U1),
    "CFG_SFCORE_USE_SF": (0x10080001, L),
    "CFG_SFIMU_ACCEL_ACCURACY": (0x30060018, U2),
    "CFG_SFIMU_ACCEL_FREQUENCY": (0x20060016, U1),
    "CFG_SFIMU_ACCEL_LATENCY": (0x30060017, U2),
    "CFG_SFIMU_ACCEL_RMSTHDL": (0x20060015, U1),
    "CFG_SFIMU_AUTO_MNTALG_ENA": (0x10060027, L),
    "CFG_SFIMU_GYRO_ACCURACY": (0x3006000B, U2),
    "CFG_SFIMU_GYRO_FREQUENCY": (0x20060009, U1),
    "CFG_SFIMU_GYRO_LATENCY": (0x3006000A, U2),
    "CFG_SFIMU_GYRO_RMSTHDL": (0x20060008, U1),
    "CFG_SFIMU_GYRO_TC_UPDATE_PERIOD": (0x30060007, U2),
    "CFG_SFIMU_IMU_EN": (0x1006001D, L),
    "CFG_SFIMU_IMU_I2C_SCL_PIO": (0x2006001E, U1),
    "CFG_SFIMU_IMU_I2C_SDA_PIO": (0x2006001F, U1),
    "CFG_SFIMU_IMU_MNTALG_PITCH": (0x3006002E, I2),
    "CFG_SFIMU_IMU_MNTALG_ROLL": (0x3006002F, I2),
    "CFG_SFIMU_IMU_MNTALG_YAW": (0x4006002D, U4),
    "CFG_SFODO_CNT_BOTH_EDGES": (0x1007000D, L),
    "CFG_SFODO_COMBINE_TICKS": (0x10070001, L),
    "CFG_SFODO_COUNT_MAX": (0x40070009, U4),
    "CFG_SFODO_DIR_PINPOL": (0x10070010, L),
    "CFG_SFODO_DIS_AUTOCOUNTMAX": (0x10070004, L),
    "CFG_SFODO_DIS_AUTODIRPINPOL": (0x10070005, L),
    "CFG_SFODO_DIS_AUTOSPEED": (0x10070006, L),
    "CFG_SFODO_DIS_AUTOSW": (0x10070011, L),
    "CFG_SFODO_FACTOR": (0x40070007, U4),
    "CFG_SFODO_FREQUENCY": (0x2007000B, U1),
    "CFG_SFODO_LATENCY": (0x3007000A, U2),
    "CFG_SFODO_QUANT_ERROR": (0x40070008, U4),
    "CFG_SFODO_SPEED_BAND": (0x3007000E, U2),
    "CFG_SFODO_USE_SPEED": (0x10070003, L),
    "CFG_SFODO_USE_WT_PIN": (0x1007000F, L),
    "CFG_SIGNAL_BDS_B1_ENA": (0x1031000D, L),
    "CFG_SIGNAL_BDS_B1C_ENA": (0x1031000F, L),
    "CFG_SIGNAL_BDS_B2_ENA": (0x1031000E, L),
    "CFG_SIGNAL_BDS_B2A_ENA": (0x10310028, L),
    "CFG_SIGNAL_BDS_ENA": (0x10310022, L),
    "CFG_SIGNAL_GAL_E1_ENA": (0x10310007, L),
    "CFG_SIGNAL_GAL_E5A_ENA": (0x10310009, L),
    "CFG_SIGNAL_GAL_E5B_ENA": (0x1031000A, L),
    "CFG_SIGNAL_GAL_ENA": (0x10310021, L),
    "CFG_SIGNAL_GLO_ENA": (0x10310025, L),
    "CFG_SIGNAL_GLO_L1_ENA": (0x10310018, L),
    "CFG_SIGNAL_GLO_L2_ENA": (0x1031001A, L),
    "CFG_SIGNAL_GPS_ENA": (0x1031001F, L),
    "CFG_SIGNAL_GPS_L1CA_ENA": (0x10310001, L),
    "CFG_SIGNAL_GPS_L2C_ENA": (0x10310003, L),
    "CFG_SIGNAL_GPS_L5_ENA": (0x10310004, L),
    "CFG_SIGNAL_IMES_ENA": (0x10310023, L),
    "CFG_SIGNAL_IMES_L1_ENA": (0x10310011, L),
    "CFG_SIGNAL_QZSS_ENA": (0x10310024, L),
    "CFG_SIGNAL_QZSS_L1CA_ENA": (0x10310012, L),
    "CFG_SIGNAL_QZSS_L1S_ENA": (0x10310014, L),
    "CFG_SIGNAL_QZSS_L2C_ENA": (0x10310015, L),
    "CFG_SIGNAL_QZSS_L5_ENA": (0x10310017, L),
    "CFG_SIGNAL_SBAS_ENA": (0x10310020, L),
    "CFG_SIGNAL_SBAS_L1CA_ENA": (0x10310005, L),
    "CFG_SPARTN_USE_SOURCE": (0x20A70001, E1),
    "CFG_SPI_CPHASE": (0x10640003, L),
    "CFG_SPI_CPOLARITY": (0x10640002, L),
    "CFG_SPI_ENABLED": (0x10640006, L),
    "CFG_SPI_EXTENDEDTIMEOUT": (0x10640005, L),
    "CFG_SPI_MAXFF": (0x20640001, U1),
    "CFG_SPIINPROT_NMEA": (0x10790002, L),
    "CFG_SPIINPROT_RTCM2X": (0x10790003, L),
    "CFG_SPIINPROT_RTCM3X": (0x10790004, L),
    "CFG_SPIINPROT_SPARTN": (0x10790005, L),
    "CFG_SPIINPROT_UBX": (0x10790001, L),
    "CFG_SPIOUTPROT_NMEA": (0x107A0002, L),
    "CFG_SPIOUTPROT_RTCM3X": (0x107A0004, L),
    "CFG_SPIOUTPROT_UBX": (0x107A0001, L),
    "CFG_TMODE_ECEF_X_HP": (0x20030006, I1),
    "CFG_TMODE_ECEF_X": (0x40030003, I4),
    "CFG_TMODE_ECEF_Y_HP": (0x20030007, I1),
    "CFG_TMODE_ECEF_Y": (0x40030004, I4),
    "CFG_TMODE_ECEF_Z_HP": (0x20030008, I1),
    "CFG_TMODE_ECEF_Z": (0x40030005, I4),
    "CFG_TMODE_FIXED_POS_ACC": (0x4003000F, U4),
    "CFG_TMODE_HEIGHT_HP": (0x2003000E, I1),
    "CFG_TMODE_HEIGHT": (0x4003000B, I4),
    "CFG_TMODE_LAT_HP": (0x2003000C, I1),
    "CFG_TMODE_LAT": (0x40030009, I4),
    "CFG_TMODE_LON_HP": (0x2003000D, I1),
    "CFG_TMODE_LON": (0x4003000A, I4),
    "CFG_TMODE_MODE": (0x20030001, E1),
    "CFG_TMODE_POS_TYPE": (0x20030002, E1),
    "CFG_TMODE_SVIN_ACC_LIMIT": (0x40030011, U4),
    "CFG_TMODE_SVIN_MIN_DUR": (0x40030010, U4),
    "CFG_TP_ALIGN_TO_TOW_TP1": (0x1005000A, L),
    "CFG_TP_ALIGN_TO_TOW_TP2": (0x10050015, L),
    "CFG_TP_ALIGN_TO_TOW_TP3": (0x10050020, L),
    "CFG_TP_ANT_CABLEDELAY": (0x30050001, I2),
    "CFG_TP_DRSTR_TP1": (0x20050035, E1),
    "CFG_TP_DRSTR_TP2": (0x20050036, E1),
    "CFG_TP_DUTY_LOCK_TP1": (0x5005002B, R8),
    "CFG_TP_DUTY_LOCK_TP2": (0x5005002D, R8),
    "CFG_TP_DUTY_LOCK_TP3": (0x5005002F, R8),
    "CFG_TP_DUTY_TP1": (0x5005002A, R8),
    "CFG_TP_DUTY_TP2": (0x5005002C, R8),
    "CFG_TP_DUTY_TP3": (0x5005002E, R8),
    "CFG_TP_FREQ_LOCK_TP1": (0x40050025, U4),
    "CFG_TP_FREQ_LOCK_TP2": (0x40050027, U4),
    "CFG_TP_FREQ_LOCK_TP3": (0x40050029, U4),
    "CFG_TP_FREQ_TP1": (0x40050024, U4),
    "CFG_TP_FREQ_TP2": (0x40050026, U4),
    "CFG_TP_FREQ_TP3": (0x40050028, U4),
    "CFG_TP_LEN_LOCK_TP1": (0x40050005, U4),
    "CFG_TP_LEN_LOCK_TP2": (0x40050010, U4),
    "CFG_TP_LEN_LOCK_TP3": (0x4005001B, U4),
    "CFG_TP_LEN_TP1": (0x40050004, U4),
    "CFG_TP_LEN_TP2": (0x4005000F, U4),
    "CFG_TP_LEN_TP3": (0x4005001A, U4),
    "CFG_TP_PERIOD_LOCK_TP1": (0x40050003, U4),
    "CFG_TP_PERIOD_LOCK_TP2": (0x4005000E, U4),
    "CFG_TP_PERIOD_LOCK_TP3": (0x40050019, U4),
    "CFG_TP_PERIOD_TP1": (0x40050002, U4),
    "CFG_TP_PERIOD_TP2": (0x4005000D, U4),
    "CFG_TP_PERIOD_TP3": (0x40050018, U4),
    "CFG_TP_POL_TP1": (0x1005000B, L),
    "CFG_TP_POL_TP2": (0x10050016, L),
    "CFG_TP_POL_TP3": (0x10050021, L),
    "CFG_TP_PULSE_DEF": (0x20050023, E1),
    "CFG_TP_PULSE_LENGTH_DEF": (0x20050030, E1),
    "CFG_TP_SYNC_GNSS_TP1": (0x10050008, L),
    "CFG_TP_SYNC_GNSS_TP2": (0x10050013, L),
    "CFG_TP_SYNC_GNSS_TP3": (0x1005001E, L),
    "CFG_TP_TIMEGRID_TP1": (0x2005000C, E1),
    "CFG_TP_TIMEGRID_TP2": (0x20050017, E1),
    "CFG_TP_TIMEGRID_TP3": (0x20050022, E1),
    "CFG_TP_TP1_ENA": (0x10050007, L),
    "CFG_TP_TP2_ENA": (0x10050012, L),
    "CFG_TP_TP3_ENA": (0x1005001D, L),
    "CFG_TP_USE_LOCKED_TP1": (0x10050009, L),
    "CFG_TP_USE_LOCKED_TP2": (0x10050014, L),
    "CFG_TP_USE_LOCKED_TP3": (0x1005001F, L),
    "CFG_TP_USER_DELAY_TP1": (0x40050006, I4),
    "CFG_TP_USER_DELAY_TP2": (0x40050011, I4),
    "CFG_TP_USER_DELAY_TP3": (0x4005001C, I4),
    "CFG_TXREADY_ENABLED": (0x10A20001, L),
    "CFG_TXREADY_INTERFACE": (0x20A20005, E1),
    "CFG_TXREADY_PIN": (0x20A20003, U1),
    "CFG_TXREADY_POLARITY": (0x10A20002, L),
    "CFG_TXREADY_THRESHOLD": (0x30A20004, U2),
    "CFG_UART1_BAUDRATE": (0x40520001, U4),
    "CFG_UART1_DATABITS": (0x20520003, E1),
    "CFG_UART1_ENABLED": (0x10520005, L),
    "CFG_UART1_PARITY": (0x20520004, E1),
    "CFG_UART1_REMAP": (0x10520006, L),
    "CFG_UART1_STOPBITS": (0x20520002, E1),
    "CFG_UART1INPROT_NMEA": (0x10730002, L),
    "CFG_UART1INPROT_RTCM2X": (0x10730003, L),
    "CFG_UART1INPROT_RTCM3X": (0x10730004, L),
    "CFG_UART1INPROT_SPARTN": (0x10730005, L),
    "CFG_UART1INPROT_UBX": (0x10730001, L),
    "CFG_UART1OUTPROT_NMEA": (0x10740002, L),
    "CFG_UART1OUTPROT_RTCM3X": (0x10740004, L),
    "CFG_UART1OUTPROT_UBX": (0x10740001, L),
    "CFG_UART2_BAUDRATE": (0x40530001, U4),
    "CFG_UART2_DATABITS": (0x20530003, E1),
    "CFG_UART2_ENABLED": (0x10530005, L),
    "CFG_UART2_PARITY": (0x20530004, E1),
    "CFG_UART2_REMAP": (0x10530006, L),
    "CFG_UART2_STOPBITS": (0x20530002, E1),
    "CFG_UART2INPROT_NMEA": (0x10750002, L),
    "CFG_UART2INPROT_RTCM2X": (0x10750003, L),
    "CFG_UART2INPROT_RTCM3X": (0x10750004, L),
    "CFG_UART2INPROT_SPARTN": (0x10750005, L),
    "CFG_UART2INPROT_UBX": (0x10750001, L),
    "CFG_UART2OUTPROT_NMEA": (0x10760002, L),
    "CFG_UART2OUTPROT_RTCM3X": (0x10760004, L),
    "CFG_UART2OUTPROT_UBX": (0x10760001, L),
    "CFG_USB_ENABLED": (0x10650001, L),
    "CFG_USB_POWER": (0x3065000C, U2),
    "CFG_USB_PRODUCT_ID": (0x3065000B, U2),
    "CFG_USB_PRODUCT_STR0": (0x50650011, X8),
    "CFG_USB_PRODUCT_STR1": (0x50650012, X8),
    "CFG_USB_PRODUCT_STR2": (0x50650013, X8),
    "CFG_USB_PRODUCT_STR3": (0x50650014, X8),
    "CFG_USB_SELFPOW": (0x10650002, L),
    "CFG_USB_SERIAL_NO_STR0": (0x50650015, X8),
    "CFG_USB_SERIAL_NO_STR1": (0x50650016, X8),
    "CFG_USB_SERIAL_NO_STR2": (0x50650017, X8),
    "CFG_USB_SERIAL_NO_STR3": (0x50650018, X8),
    "CFG_USB_VENDOR_ID": (0x3065000A, U2),
    "CFG_USB_VENDOR_STR0": (0x5065000D, X8),
    "CFG_USB_VENDOR_STR1": (0x5065000E, X8),
    "CFG_USB_VENDOR_STR2": (0x5065000F, X8),
    "CFG_USB_VENDOR_STR3": (0x50650010, X8),
    "CFG_USBINPROT_NMEA": (0x10770002, L),
    "CFG_USBINPROT_RTCM2X": (0x10770003, L),
    "CFG_USBINPROT_RTCM3X": (0x10770004, L),
    "CFG_USBINPROT_SPARTN": (0x10770005, L),
    "CFG_USBINPROT_UBX": (0x10770001, L),
    "CFG_USBOUTPROT_NMEA": (0x10780002, L),
    "CFG_USBOUTPROT_RTCM3X": (0x10780004, L),
    "CFG_USBOUTPROT_UBX": (0x10780001, L),
}
